@@ -284,7 +284,11 @@ class CohesityClient(object):
                  password=None,
                  domain=None,
                  auth_token=None,
-                 api_key=None):
+                 api_key=None,
+                 open_id_token=None,
+                 session_id=None,
+                 otp_code=None,
+                 otp_type=None):
 
         self.auth = AuthManager()
         self.config = Configuration()
@@ -300,6 +304,14 @@ class CohesityClient(object):
             self.config.auth_token = None  # Flushing existing token.
         if domain is not None:
             self.config.domain = domain
-        self.config.cluster_vip = cluster_vip
+        if open_id_token is not None:
+            self.config.open_id_token = open_id_token
+        if session_id is not None:
+            self.config.session_id = session_id
         if api_key is not None:
             self.config.api_key = api_key
+        if otp_code is not None:
+            self.config.otp_code = otp_code
+        if otp_type is not None:
+            self.config.otp_type = otp_type
+        self.config.cluster_vip = cluster_vip
