@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import logging
 from cohesity_management_sdk.api_helper import APIHelper
@@ -121,7 +121,7 @@ class MonitoringController(BaseController):
                 Protection Source environment. 'kPuppeteer' indicates the
                 Cohesity's Remote Adapter. 'kPhysical' indicates the physical
                 Protection Source environment. 'kPure' indicates the Pure
-                Storage Protection Source environment. 'Nimble' indicates the
+                Storage Protection Source environment. 'kNimble' indicates the
                 Nimble Storage Protection Source environment. 'kAzure'
                 indicates the Microsoft's Azure Protection Source environment.
                 'kNetapp' indicates the Netapp Protection Source environment.
@@ -157,8 +157,20 @@ class MonitoringController(BaseController):
                 Couchbase Protection Source environment. 'kHdfs' indicates
                 Hdfs Protection Source environment. 'kHive' indicates Hive
                 Protection Source environment. 'kHBase' indicates HBase
-                Protection Source environment. 'kUDA' indicates Universal Data
-                Adapter Protection Source environment.
+                Protection Source environment. 'kUDA' indicates Universal
+                Data Adapter Protection Source environment.
+                'kO365Teams' indicates the Office365 Teams Protection Source
+                environment.
+                'kO365Group' indicates the Office365 Groups Protection Source
+                environment.
+                'kO365Exchange' indicates the Office365 Mailbox Protection
+                Source environment.
+                'kO365OneDrive' indicates the Office365 OneDrive Protection
+                Source environment.
+                'kO365Sharepoint' indicates the Office365 SharePoint Protection
+                Source environment.
+                'kO365PublicFolders' indicates the Office365 PublicFolders
+                Protection Source environment.
             page (int, optional): Specifies the page number in case of
                 pagination of response.
             page_size (int, optional): Specifies the size of the page in case
