@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import logging
 from cohesity_management_sdk.api_helper import APIHelper
@@ -28,6 +28,7 @@ class ProtectionSourcesController(BaseController):
 
     def get_download_physical_agent(self,
                                     host_type,
+                                    host_os_type=None,
                                     pkg_type=None,
                                     agent_type=None):
         """Does a GET request to /public/physicalAgents/download.
@@ -43,6 +44,8 @@ class ProtectionSourcesController(BaseController):
                 the Oracle Solaris operating system. 'kSapHana' indicates the
                 Sap Hana database system developed by SAP SE. 'kOther'
                 indicates the other types of operating system.
+            host_os_type(HostOSTypeEnum, optional): Specifies the OS type for
+                which user wants to download the physical agent/plugin.
             pkg_type (PkgTypeEnum, optional): Specifies the Linux installer
                 package type applicable only to Linux OS and the value can be
                 any of ("kScript","kRPM", "kSuseRPM", "kDEB") 'kScript'
@@ -81,6 +84,7 @@ class ProtectionSourcesController(BaseController):
             _query_builder += _url_path
             _query_parameters = {
                 'hostType': host_type,
+                'hostOSType': host_os_type,
                 'pkgType': pkg_type,
                 'agentType': agent_type
             }
@@ -203,6 +207,8 @@ class ProtectionSourcesController(BaseController):
             raise
 
     def list_protection_sources(self,
+                                exclude_office_365_types=None,
+                                get_teams_channels=None,
                                 after_cursor_entity_id=None,
                                 before_cursor_entity_id=None,
                                 node_id=None,
@@ -213,6 +219,7 @@ class ProtectionSourcesController(BaseController):
                                 num_levels=None,
                                 exclude_types=None,
                                 exclude_aws_types=None,
+                                exclude_kubernetes_types=None,
                                 include_datastores=None,
                                 include_networks=None,
                                 include_vm_folders=None,
@@ -223,6 +230,10 @@ class ProtectionSourcesController(BaseController):
                                 sids=None,
                                 include_source_credentials=None,
                                 encryption_key=None,
+                                include_object_protection_info=None,
+                                prune_non_critical_info=None,
+                                request_initiator_type=None,
+                                use_cached_data=None,
                                 tenant_ids=None,
                                 all_under_hierarchy=None):
         """Does a GET request to /public/protectionSources.
@@ -241,6 +252,16 @@ class ProtectionSourcesController(BaseController):
 
 
         Args:
+            exclude_office_365_types (list of ExcludeOffice365TypesEnum, optional):
+                Specifies the Object types to be filtered out for Office 365
+                that match the passed in types such as 'kDomain', 'kOutlook',
+                'kMailbox', etc.
+                For example, set this parameter to 'kMailbox' to exclude
+                Mailbox Objects from being returned.
+            get_teams_channels (bool): Specifies whether to get the list of the
+                channels for a given M365 Teams object. This should be set to true
+                only when a single Id belonging to M365 Teams object is provided
+                in the query params.
             after_cursor_entity_id (long|int, optional): Specifies the entity
                 id starting from which the items are to be returned.
             before_cursor_entity_id (long|int, optional): Specifies the entity
@@ -266,11 +287,16 @@ class ProtectionSourcesController(BaseController):
                 'kHostSystem', 'kVirtualMachine', etc. For example, set this
                 parameter to 'kResourcePool' to exclude Resource Pool Objects
                 from being returned.
-            exclude_aws_types (list of ExcludeAwsTypeEnum, optional): Specifies
-                the Object types to be filtered out for AWS that match the
-                passed in types such as 'kEC2Instance', 'kRDSInstance' etc.
-                For example, set this parameter to 'kEC2Instance' to exclude
-                ec2 instance from being returned.
+            exclude_aws_types (list of ExcludeAwsTypesEnum, optional): Specifies
+                the Object types to be filtered out for AWS that match the passed
+                in types such as 'kEC2Instance', 'kRDSInstance' & 'kAuroraCluster'.
+                For example, set this parameter to 'kEC2Instance' to exclude ec2
+                instance from being returned.
+            exclude_kubernetes_types (list of ExcludeKubernetesTypesEnum, optional):
+                Specifies the Object types to be filtered out for Kubernetes
+                that match the passed in types such as 'kService'.
+                For example, set this parameter to 'kService' to exclude services
+                from being returned.
             include_datastores (bool, optional): Set this parameter to true to
                 also return kDatastore object types found in the Source in
                 addition to their Object subtrees. By default, datastores are
@@ -310,6 +336,23 @@ class ProtectionSourcesController(BaseController):
             encryption_key (string, optional): Key to be used to encrypt the
                 source credential. If include_source_credentials is set to true
                 this key must be specified.
+            include_object_protection_info (bool): If specified, the object
+                protection of entities(if any) will be returned.
+            prune_non_critical_info (bool): Specifies whether to prune non
+                critical info within entities. Incase of VMs, virtual disk
+                information will be pruned. Incase of Office365, metadata about
+                user entities will be pruned. This can be used to limit the size
+                of the response by caller.
+            request_initiator_type (string): Specifies the type of the request.
+                Possible values are UIUser and UIAuto, which means the request
+                is triggered by user or is an auto refresh request. Services
+                like magneto will use this to determine the priority of the
+                requests, so that it can more intelligently handle overload
+                situations by prioritizing higher priority requests.
+            use_cached_data (bool): Specifies whether we can serve the GET
+                request to the read replica cache. setting this to true ensures
+                that the API request is served to the read replica. setting this
+                to false will serve the request to the master.
             tenant_ids (list of string, optional): TenantIds contains ids of
                 the tenants for which objects are to be returned.
             all_under_hierarchy (bool, optional): AllUnderHierarchy specifies
@@ -336,6 +379,8 @@ class ProtectionSourcesController(BaseController):
             _query_builder = self.config.get_base_uri()
             _query_builder += _url_path
             _query_parameters = {
+                'getTeamsChannels': get_teams_channels,
+                'excludeOffice365Types': exclude_office_365_types,
                 'afterCursorEntityId': after_cursor_entity_id,
                 'beforeCursorEntityId': before_cursor_entity_id,
                 'nodeId': node_id,
@@ -346,6 +391,7 @@ class ProtectionSourcesController(BaseController):
                 'numLevels': num_levels,
                 'excludeTypes': exclude_types,
                 'excludeAwsTypes': exclude_aws_types,
+                'excludeKubernetesTypes': exclude_kubernetes_types,
                 'includeDatastores': include_datastores,
                 'includeNetworks': include_networks,
                 'includeVMFolders': include_vm_folders,
@@ -356,6 +402,10 @@ class ProtectionSourcesController(BaseController):
                 'sids': sids,
                 'includeSourceCredentials': include_source_credentials,
                 'encryptionKey': encryption_key,
+                'includeObjectProtectionInfo': include_object_protection_info,
+                'pruneNonCriticalInfo': prune_non_critical_info,
+                'requestInitiatorType': request_initiator_type,
+                'useCachedData': use_cached_data,
                 'tenantIds': tenant_ids,
                 'allUnderHierarchy': all_under_hierarchy
             }
@@ -420,7 +470,7 @@ class ProtectionSourcesController(BaseController):
                 environment. 'kPuppeteer' indicates the Cohesity's Remote
                 Adapter. 'kPhysical' indicates the physical Protection Source
                 environment. 'kPure' indicates the Pure Storage Protection
-                Source environment. 'Nimble' indicates the Nimble Storage
+                Source environment. 'kNimble' indicates the Nimble Storage
                 Protection Source environment. 'kAzure' indicates the
                 Microsoft's Azure Protection Source environment. 'kNetapp'
                 indicates the Netapp Protection Source environment. 'kAgent'
@@ -456,8 +506,8 @@ class ProtectionSourcesController(BaseController):
                 indicates Couchbase Protection Source environment. 'kHdfs'
                 indicates Hdfs Protection Source environment. 'kHive'
                 indicates Hive Protection Source environment. 'kHBase'
-                indicates HBase Protection Source environment.
-
+                indicates HBase Protection Source environment. 'kUDA'
+                indicates Universal Data Adapter Protection Source environment.
             protection_source_id (long|int, optional): Specifies the
                 Protection Source Id of the 'kPhysical' or 'kVMware' entity in
                 the Protection Source tree hosting the applications.
@@ -472,7 +522,7 @@ class ProtectionSourcesController(BaseController):
                 Protection Source environment. 'kPuppeteer' indicates the
                 Cohesity's Remote Adapter. 'kPhysical' indicates the physical
                 Protection Source environment. 'kPure' indicates the Pure
-                Storage Protection Source environment. 'Nimble' indicates the
+                Storage Protection Source environment. 'kNimble' indicates the
                 Nimble Storage Protection Source environment. 'kAzure'
                 indicates the Microsoft's Azure Protection Source environment.
                 'kNetapp' indicates the Netapp Protection Source environment.
@@ -509,8 +559,8 @@ class ProtectionSourcesController(BaseController):
                 environment. 'kHdfs' indicates Hdfs Protection Source
                 environment. 'kHive' indicates Hive Protection Source
                 environment. 'kHBase' indicates HBase Protection Source
-                environment.
-
+                environment.'kUDA' indicates Universal Data Adapter Protection
+                Source environment.
 
         Returns:
             list of RegisteredApplicationServer: Response from the API.
@@ -1192,7 +1242,8 @@ class ProtectionSourcesController(BaseController):
                                environment,
                                id,
                                all_under_hierarchy=None,
-                               include_rpo_snapshots=None):
+                               include_rpo_snapshots=None,
+                               prune_protection_job_metadata=None):
         """Does a GET request to /public/protectionSources/protectedObjects.
 
         Returns the list of protected Objects in a registered Protection
@@ -1214,7 +1265,7 @@ class ProtectionSourcesController(BaseController):
                 environment. 'kPuppeteer' indicates the Cohesity's Remote
                 Adapter. 'kPhysical' indicates the physical Protection Source
                 environment. 'kPure' indicates the Pure Storage Protection
-                Source environment. 'Nimble' indicates the Nimble Storage
+                Source environment. 'kNimble' indicates the Nimble Storage
                 Protection Source environment. 'kAzure' indicates the
                 Microsoft's Azure Protection Source environment. 'kNetapp'
                 indicates the Netapp Protection Source environment. 'kAgent'
@@ -1251,6 +1302,15 @@ class ProtectionSourcesController(BaseController):
                 Source environment. 'kHdfs' indicates Hdfs Protection Source
                 environment. 'kHive' indicates Hive Protection Source
                 environment. 'kHBase' indicates HBase Protection Source
+                environment. 'kUDA' indicates Universal Data Adapter Protection
+                Source environment. 'kO365Teams' indicates the Office365 Teams
+                Protection Source environment. 'kO365Group' indicates the
+                Office365 Groups Protection Source environment. 'kO365Exchange'
+                indicates the Office365 Mailbox Protection Source environment.
+                'kO365OneDrive' indicates the Office365 OneDrive Protection
+                Source environment.'kO365Sharepoint' indicates the Office365
+                SharePoint Protection Source environment.'kO365PublicFolders'
+                indicates the Office365 PublicFolders Protection Source
                 environment.
             id (long|int): Specifies the Id of a registered Protection Source
                 of the type given in environment.
@@ -1260,6 +1320,11 @@ class ProtectionSourcesController(BaseController):
             include_rpo_snapshots (bool, optional): If true, then the
                 Protected Objects protected by RPO policies will also be
                 returned.
+            prune_protection_job_metadata (bool, optional): Specifies whether
+                the metadata about the protection job is to be pruned. If set
+                to true, only ID, name & policy info will be returned. Info
+                about indexing, entities within the job and other additional
+                settings will be omitted.
 
         Returns:
             list of ProtectedVmInfo: Response from the API. Success
@@ -1288,7 +1353,8 @@ class ProtectionSourcesController(BaseController):
                 'environment': environment,
                 'id': id,
                 'allUnderHierarchy': all_under_hierarchy,
-                'includeRpoSnapshots': include_rpo_snapshots
+                'includeRpoSnapshots': include_rpo_snapshots,
+                'pruneProtectionJobMetadata': prune_protection_job_metadata
             }
             _query_builder = APIHelper.append_url_with_query_parameters(
                 _query_builder, _query_parameters,
@@ -1481,6 +1547,9 @@ class ProtectionSourcesController(BaseController):
         encryption_key=None,
         include_applications_tree_info=None,
         tenant_ids=None,
+        prune_non_critical_info=None,
+        request_initiator_type=None,
+        use_cached_data=None,
         all_under_hierarchy=None):
         """Does a GET request to /public/protectionSources/registrationInfo.
 
@@ -1512,6 +1581,22 @@ class ProtectionSourcesController(BaseController):
             encryption_key (string, optional): Key to be used to encrypt the
                 source credential. If include_source_credentials is set to true
                 this key must be specified.
+            prune_non_critical_info (bool, optional): Specifies whether to
+                prune non critical info within entities. Incase of VMs,
+                virtual disk information will be pruned. Incase of
+                Office365, metadata about user entities will be pruned. This
+                can be used to limit the size of the response by caller.
+            request_initiator_type (str, optional): Specifies the type of the
+                request. Possible values are UIUser and UIAuto, which means the
+                request is triggered by user or is an auto refresh request.
+                Services like magneto will use this to determine the priority
+                of the requests, so that it can more intelligently handle
+                overload situations by prioritizing higher priority requests.
+            use_cached_data (bool, optional): Specifies whether we can serve
+                the GET request to the read replica cache. setting this to
+                true ensures that the API request is served to the read
+                replica. setting this to false will serve the request to the
+                master.
             include_applications_tree_info (bool, optional): Specifies whether
                 to return applications tree info or not.
             tenant_ids (list of string, optional): TenantIds contains ids of
@@ -1550,6 +1635,9 @@ class ProtectionSourcesController(BaseController):
                 'encryptionKey': encryption_key,
                 'includeApplicationsTreeInfo':include_applications_tree_info,
                 'tenantIds': tenant_ids,
+                'pruneNonCriticalInfo': prune_non_critical_info,
+                'requestInitiatorType': request_initiator_type,
+                'useCachedData': use_cached_data,
                 'allUnderHierarchy': all_under_hierarchy
             }
             _query_builder = APIHelper.append_url_with_query_parameters(
