@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import logging
 from cohesity_management_sdk.api_helper import APIHelper
@@ -109,8 +109,6 @@ class StatsController(BaseController):
 
     def get_consumer_stats(self,
                            consumer_type=None,
-                           max_count=None,
-                           cookie=None,
                            consumer_id_list=None,
                            consumer_entity_id_list=None,
                            fetch_view_box_name=None,
@@ -121,7 +119,9 @@ class StatsController(BaseController):
                            organizations_id_list=None,
                            tenant_ids=None,
                            include_service_provider=None,
-                           msecs_before_current_time_to_compare=None):
+                           msecs_before_current_time_to_compare=None,
+                           max_count=None,
+                           cookie=None):
         """Does a GET request to /public/stats/consumers.
 
         Gets the statistics of consumers.
@@ -136,12 +136,6 @@ class StatsController(BaseController):
                 (storage domain). 'kReplicationRuns', indicates the stats info
                 of Replication In used per organization (tenant) per view box
                 (storage domain).
-            max_count (long|int, optional): Specifies a limit on the number of
-                stats groups returned.
-            cookie (string, optional): Specifies the opaque string returned in
-                the previous response. If this is set, next set of active
-                opens just after the previous response are returned. If this
-                is not set, first set of active opens are returned.
             consumer_id_list (list of long|int, optional): Specifies a list of
                 consumer ids.
             consumer_entity_id_list (list of string, optional): Specifies a
@@ -173,8 +167,14 @@ class StatsController(BaseController):
                 fetch the consumption of external service providers. These
                 information will be listed as a unique organization (tenant) in
                 response. By default it is false.
-            msecs_before_current_time_to_compare (bool, optional): Specifies the
-                time in msecs before current time to compare with.
+            msecs_before_current_time_to_compare (long|int, optional): Specifies
+                the time in msecs before current time to compare with.
+            max_count (long|int, optional): Specifies a limit on the number of
+                stats groups returned.
+            cookie (string, optional): Specifies the opaque string returned in
+                the previous response. If this is set, next set of active
+                opens just after the previous response are returned. If this
+                is not set, first set of active opens are returned.
 
         Returns:
             GetConsumerStatsResult: Response from the API. Success
@@ -196,8 +196,6 @@ class StatsController(BaseController):
             _query_builder += _url_path
             _query_parameters = {
                 'consumerType': consumer_type,
-                'maxCount': max_count,
-                'cookie': cookie,
                 'consumerIdList': consumer_id_list,
                 'consumerEntityIdList': consumer_entity_id_list,
                 'fetchViewBoxName': fetch_view_box_name,
@@ -208,6 +206,8 @@ class StatsController(BaseController):
                 'organizationsIdList': organizations_id_list,
                 'tenantIds': tenant_ids,
                 'includeServiceProvider': include_service_provider,
+                'maxCount': max_count,
+                'cookie': cookie,
                 'msecsBeforeCurrentTimeToCompare': msecs_before_current_time_to_compare
             }
             _query_builder = APIHelper.append_url_with_query_parameters(
@@ -399,11 +399,23 @@ class StatsController(BaseController):
             self.logger.error(e, exc_info=True)
             raise
 
-    def get_last_protection_run_stats(self):
+    def get_last_protection_run_stats(self,
+                                      from_time_secs=None,
+                                      to_time_secs=None):
         """Does a GET request to /public/stats/protectionRuns/lastRun.
 
         Compute stats on last Protection Run for every job.
 
+        Args:
+            from_time_secs (long|int, optional): Specifies the time in Unix
+                timestamp epoch in microsecond which filters all the runs
+                started after this value. If not specified, this will be set
+                to 24 hours prior to toTimeUsecs parameter.
+            to_time_secs (long|int, optional): Specifies the time in Unix
+                timestamp epoch in microsecond which filters all the runs
+                started before this value. If not specified, this will
+                be set to 24 hours ahead of fromTimeUsecs parameter.
+
         Returns:
             LastProtectionRunStats: Response from the API. Success
 
@@ -423,6 +435,13 @@ class StatsController(BaseController):
             _url_path = '/public/stats/protectionRuns/lastRun'
             _query_builder = self.config.get_base_uri()
             _query_builder += _url_path
+            _query_parameters = {
+                'fromTimeUsecs': from_time_secs,
+                'toTimeUsecs': to_time_secs
+                }
+            _query_builder = APIHelper.append_url_with_query_parameters(
+                _query_builder, _query_parameters,
+                Configuration.array_serialization)
             _query_url = APIHelper.clean_url(_query_builder)
 
             # Prepare headers
@@ -649,8 +668,7 @@ class StatsController(BaseController):
                          view_boxes_id_list=None,
                          organizations_id_list=None,
                          tenant_ids=None,
-                         include_service_provider=None,
-                         msecs_before_current_time_to_compare=None):
+                         include_service_provider=None):
         """Does a GET request to /public/stats/tenants.
 
         Gets the statistics of organizations (tenant).
@@ -693,8 +711,6 @@ class StatsController(BaseController):
                 fetch the consumption of external service providers. These
                 information will be listed as a unique organization (tenant) in
                 response. By default it is false.
-            msecs_before_current_time_to_compare (bool, optional): Specifies the
-                time in msecs before current time to compare with.
 
         Returns:
             GetTenantStatsResult: Response from the API. Success
@@ -723,8 +739,7 @@ class StatsController(BaseController):
                 'viewBoxesIdList': view_boxes_id_list,
                 'organizationsIdList': organizations_id_list,
                 'tenantIds': tenant_ids,
-                'includeServiceProvider': include_service_provider,
-                'msecsBeforeCurrentTimeToCompare': msecs_before_current_time_to_compare
+                'includeServiceProvider': include_service_provider
             }
             _query_builder = APIHelper.append_url_with_query_parameters(
                 _query_builder, _query_parameters,
@@ -961,10 +976,7 @@ class StatsController(BaseController):
                            view_boxes_id_list=None,
                            organizations_id_list=None,
                            tenant_ids=None,
-                           include_service_provider=None,
-                           msecs_before_current_time_to_compare=None,
-                           max_count=None,
-                           cookie=None):
+                           include_service_provider=None):
         """Does a GET request to /public/stats/viewBoxes.
 
         Gets the statistics of view boxes (storage domain).
@@ -982,15 +994,6 @@ class StatsController(BaseController):
                 fetch the consumption of external service providers. These
                 information will be listed as a unique organization (tenant) in
                 response. By default it is false.
-            msecs_before_current_time_to_compare (long|int, optional): Specifies
-                the time in msecs before current time to compare with.
-            max_count (long|int, optioanl): Specifies a limit on the number of stats
-                groups returned.
-            cookie (str, optional): Specifies the opaque string returned in the
-                previous response.
-                If this is set, next set of active opens just after the previous
-                response are returned. If this is not set, first set of active opens
-                are returned.
 
         Returns:
             GetViewBoxStatsResult: Response from the API. Success
@@ -1014,10 +1017,7 @@ class StatsController(BaseController):
                 'viewBoxesIdList': view_boxes_id_list,
                 'organizationsIdList': organizations_id_list,
                 'tenantIds': tenant_ids,
-                'includeServiceProvider': include_service_provider,
-                'msecsBeforeCurrentTimeToCompare': msecs_before_current_time_to_compare,
-                'maxCount': max_count,
-                'cookie': cookie
+                'includeServiceProvider': include_service_provider
             }
             _query_builder = APIHelper.append_url_with_query_parameters(
                 _query_builder, _query_parameters,
@@ -1051,7 +1051,11 @@ class StatsController(BaseController):
             self.logger.error(e, exc_info=True)
             raise
 
-    def get_view_stats(self, metric=None, num_top_views=None):
+    def get_view_stats(self,
+                       metric=None,
+                       num_top_views=None,
+                       protocol=None,
+                       last_hours=None):
         """Does a GET request to /public/stats/views.
 
         Compute the statistics on Views.
@@ -1065,6 +1069,10 @@ class StatsController(BaseController):
                 specified. If specified, minimum value is 1. If not specified,
                 all views will be returned. If metric is not specified, this
                 parameter must also not be specified.
+            last_hours (long|int, optional): Specifies the last hours of stats
+                to sort.
+            protocol (ProtocolViewStatsEnum, optional): Specifies the protocol
+                to sort.
 
         Returns:
             ViewStatsSnapshot: Response from the API. Success
@@ -1086,7 +1094,9 @@ class StatsController(BaseController):
             _query_builder += _url_path
             _query_parameters = {
                 'metric': metric,
-                'numTopViews': num_top_views
+                'numTopViews': num_top_views,
+                'lastHours': last_hours,
+                'protocol': protocol
             }
             _query_builder = APIHelper.append_url_with_query_parameters(
                 _query_builder, _query_parameters,
