@@ -210,6 +210,7 @@ __all__ = [
     'c2s_access_portal',
     'c2s_server_info',
     'c_2_s_access_portal',
+    'c_2_s_server_info',
     'cancel_protection_job_run_param',
     'capacity_by_tier',
     'cassandra_additional_params',
@@ -625,6 +626,7 @@ __all__ = [
     'get_job_run_info_result',
     'get_kms_status_response',
     'get_linux_support_user2fa_result',
+    'get_linux_support_user_2_fa_result',
     'get_linux_support_user_2fa_result',
     'get_map_reduce_app_runs_params',
     'get_mr_jar_upload_path_result',
@@ -748,6 +750,8 @@ __all__ = [
     'job_type_enum',
     'k8_s_filter_params',
     'k8_s_filter_params_label_vec',
+    'k_8_s_filter_params',
+    'k_8_s_filter_params_label_vec',
     'k_ms_status_response',
     'key_value_pair',
     'keystone_acl_proto',
@@ -816,7 +820,7 @@ __all__ = [
     'logical_stats',
     'logical_volume',
     'logical_volume_type_enum',
-    'm365_teams_channel_info',
+    'm_365_teams_channel_info',
     'magneto_instance_id',
     'magneto_object_id',
     'mailbox_type_enum',
@@ -942,10 +946,9 @@ __all__ = [
     'notification_rule',
     'notifications',
     'ntp_settings_config',
-    'o365_backup_env_params',
-    'o365_connect_params',
-    'o365_region_proto',
     'o_365_backup_env_params',
+    'o_365_connect_params',
+    'o_365_region_proto',
     'object_class_active_directory_principals_add_parameters_enum',
     'object_class_added_active_directory_principal_enum',
     'object_class_added_idp_principal_enum',
@@ -968,19 +971,13 @@ __all__ = [
     'objects_by_env',
     'objects_discovery_params',
     'objects_protected_by_policy',
-    'office365_credentials',
-    'office365_env_job_parameters',
-    'office365_protection_source',
-    'office365_site_info',
-    'office365_team_info',
-    'office365_type_enum',
-    'office365_user_info',
     'office_365_credentials',
     'office_365_env_job_parameters',
     'office_365_protection_source',
     'office_365_protection_source_types_enum',
     'office_365_site_info',
     'office_365_source_type_enum',
+    'office_365_team_info',
     'office_365_type_enum',
     'office_365_user_info',
     'old_syslog_server',
@@ -1198,6 +1195,8 @@ __all__ = [
     'pure_volume',
     'put_linux_support_user2fa_params_with_totp',
     'put_linux_support_user2fa_result',
+    'put_linux_support_user_2_fa_params_with_totp',
+    'put_linux_support_user_2_fa_result',
     'put_linux_support_user_2fa_params_with_to_tp',
     'pvc_info',
     'pvc_info_pvc_spec',
@@ -1309,16 +1308,6 @@ __all__ = [
     'restore_kubernetes_namespaces_params',
     'restore_kvm_vms_params',
     'restore_kvmv_ms_params',
-    'restore_o365_groups_params',
-    'restore_o365_groups_params_group_granular_params',
-    'restore_o365_groups_params_ms_group_info',
-    'restore_o365_public_folders_params',
-    'restore_o365_public_folders_params_public_folder',
-    'restore_o365_public_folders_params_root_public_folder',
-    'restore_o365_teams_params',
-    'restore_o365_teams_params_ms_team_info',
-    'restore_o365_teams_params_source_channel',
-    'restore_o365_teams_params_target_channel',
     'restore_o_365_groups_params',
     'restore_o_365_groups_params_group_granular_params',
     'restore_o_365_groups_params_ms_group_info',
@@ -1327,6 +1316,8 @@ __all__ = [
     'restore_o_365_public_folders_params_root_public_folder',
     'restore_o_365_teams_params',
     'restore_o_365_teams_params_ms_team_info',
+    'restore_o_365_teams_params_source_channel',
+    'restore_o_365_teams_params_target_channel',
     'restore_object',
     'restore_object_details',
     'restore_object_params',
@@ -1401,8 +1392,12 @@ __all__ = [
     's3_bucket_info',
     's3_key_mapping_config_enum',
     's3_view_backup_properties',
+    's_3_bucket_config_proto',
+    's_3_bucket_config_proto_tag_map_entry',
+    's_3_bucket_info',
     's_3_key_mapping_config_create_view_request_enum',
     's_3_key_mapping_config_enum',
+    's_3_view_backup_properties',
     'salesforce_account_info',
     'sample',
     'san_env_job_parameters',
@@ -1731,6 +1726,7 @@ __all__ = [
     'uda_restore_object',
     'uda_restore_object_params',
     'uda_s3_view_backup_properties',
+    'uda_s_3_view_backup_properties',
     'uda_source_capabilities',
     'un_register_application_servers_parameters',
     'universal_id',
