@@ -1,35 +1,37 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.view_alias
 
+
 class ActivateViewAliasesResult(object):
 
     """Implementation of the 'ActivateViewAliasesResult' model.
 
-    Specifies the information of activated alias views created
-    for a view.
+    Specifies the information of activated alias views created for a view.
+
 
     Attributes:
-        aliases (list of ViewAlias): Aliases created for the view. A view
-            alias allows a directory path inside a view to be mounted using
-            the alias name.
 
+        aliases (list of ViewAlias): Aliases created for the view. A view alias
+            allows a directory path inside a view to be mounted using the alias
+            name.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "aliases":'aliases'
+        "aliases":'aliases',
     }
-
     def __init__(self,
-                 aliases=None):
+                 aliases=None,
+            ):
+
         """Constructor for the ActivateViewAliasesResult class"""
 
         # Initialize members of the class
         self.aliases = aliases
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -55,6 +57,6 @@ class ActivateViewAliasesResult(object):
                 aliases.append(cohesity_management_sdk.models.view_alias.ViewAlias.from_dictionary(structure))
 
         # Return an object of this model
-        return cls(aliases)
-
-
+        return cls(
+            aliases
+)
\ No newline at end of file
