@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
-import cohesity_management_sdk.models.user_id_mapping
 import cohesity_management_sdk.models.preferred_domain_controller
+import cohesity_management_sdk.models.user_id_mapping
+
 
 class ActiveDirectoryEntry(object):
 
@@ -10,19 +11,23 @@ class ActiveDirectoryEntry(object):
 
     Specifies the join settings for a Microsoft Active Directory domain.
 
+
     Attributes:
+
         domain_name (string): Specifies the fully qualified domain name (FQDN)
             of an Active Directory.
-        fallback_user_id_mapping_info (UserIdMapping): Specifies how the Unix
-            and Windows users are mapped in an Active Directory.
-        force_remove (bool): Specifies if Active Directory entry should be force
-            removed from cluster.
-        ignored_trusted_domains (list of string): Specifies the list of
-            trusted domains that were set by the user to be ignored during
-            trusted domain discovery.
+        fallback_user_id_mapping_info (UserIdMapping): Specifies the fallback
+            id mapping info which is used when an ID mapping for a user is not
+            found via the above IdMappingInfo. Only supported for two types of
+            fallback mapping types - 'kRid' and 'kFixed'.
+        force_remove (bool): Specifies if Active Directory entry should be
+            force removed from cluster.
+        ignored_trusted_domains (list of string): Specifies the list of trusted
+            domains that were set by the user to be ignored during trusted
+            domain discovery.
         ldap_provider_id (long|int): Specifies the LDAP provider id which is
             map to this Active Directory
-        machine_accounts (list of string): Array of Machine Accounts.
+        machine_accounts (list of string): Array of Machine Accounts. 
             Specifies an array of computer names used to identify the Cohesity
             Cluster on the domain.
         only_use_whitelisted_domains (bool): Specifies whether to use
@@ -40,16 +45,16 @@ class ActiveDirectoryEntry(object):
             discovery is disabled.
         unix_root_sid (string): Specifies the SID of the Active Directory
             domain user to be mapped to Unix root user.
-        user_id_mapping_info (UserIdMapping): Specifies how the Unix and
-            Windows users are mapped in an Active Directory.
+        user_id_mapping_info (UserIdMapping): Specifies the information about
+            how the Unix and Windows users are mapped for this domain.
         user_name (string): Specifies a userName that has administrative
             privileges in the domain.
-        whitelisted_domains (list of string): Specifies the Whitelisted
-            Domains of the Active Directory domain.
+        whitelisted_domains (list of string): Specifies the Whitelisted Domains
+            of the Active Directory domain.
         workgroup (string): Specifies an optional Workgroup name.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "domain_name":'domainName',
@@ -70,9 +75,8 @@ class ActiveDirectoryEntry(object):
         "user_id_mapping_info":'userIdMappingInfo',
         "user_name":'userName',
         "whitelisted_domains":'whitelistedDomains',
-        "workgroup":'workgroup'
+        "workgroup":'workgroup',
     }
-
     def __init__(self,
                  domain_name=None,
                  fallback_user_id_mapping_info=None,
@@ -92,7 +96,9 @@ class ActiveDirectoryEntry(object):
                  user_id_mapping_info=None,
                  user_name=None,
                  whitelisted_domains=None,
-                 workgroup=None):
+                 workgroup=None,
+            ):
+
         """Constructor for the ActiveDirectoryEntry class"""
 
         # Initialize members of the class
@@ -116,7 +122,6 @@ class ActiveDirectoryEntry(object):
         self.whitelisted_domains = whitelisted_domains
         self.workgroup = workgroup
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -138,9 +143,9 @@ class ActiveDirectoryEntry(object):
         domain_name = dictionary.get('domainName')
         fallback_user_id_mapping_info = cohesity_management_sdk.models.user_id_mapping.UserIdMapping.from_dictionary(dictionary.get('fallbackUserIdMappingInfo')) if dictionary.get('fallbackUserIdMappingInfo') else None
         force_remove = dictionary.get('forceRemove')
-        ignored_trusted_domains = dictionary.get('ignoredTrustedDomains')
+        ignored_trusted_domains = dictionary.get("ignoredTrustedDomains")
         ldap_provider_id = dictionary.get('ldapProviderId')
-        machine_accounts = dictionary.get('machineAccounts')
+        machine_accounts = dictionary.get("machineAccounts")
         only_use_whitelisted_domains = dictionary.get('onlyUseWhitelistedDomains')
         ou_name = dictionary.get('ouName')
         password = dictionary.get('password')
@@ -151,33 +156,33 @@ class ActiveDirectoryEntry(object):
                 preferred_domain_controllers.append(cohesity_management_sdk.models.preferred_domain_controller.PreferredDomainController.from_dictionary(structure))
         task_path = dictionary.get('taskPath')
         tenant_id = dictionary.get('tenantId')
-        trusted_domains = dictionary.get('trustedDomains')
+        trusted_domains = dictionary.get("trustedDomains")
         trusted_domains_enabled = dictionary.get('trustedDomainsEnabled')
         unix_root_sid = dictionary.get('unixRootSid')
         user_id_mapping_info = cohesity_management_sdk.models.user_id_mapping.UserIdMapping.from_dictionary(dictionary.get('userIdMappingInfo')) if dictionary.get('userIdMappingInfo') else None
         user_name = dictionary.get('userName')
-        whitelisted_domains = dictionary.get('whitelistedDomains')
+        whitelisted_domains = dictionary.get("whitelistedDomains")
         workgroup = dictionary.get('workgroup')
 
         # Return an object of this model
-        return cls(domain_name,
-                   fallback_user_id_mapping_info,
-                   force_remove,
-                   ignored_trusted_domains,
-                   ldap_provider_id,
-                   machine_accounts,
-                   only_use_whitelisted_domains,
-                   ou_name,
-                   password,
-                   preferred_domain_controllers,
-                   task_path,
-                   tenant_id,
-                   trusted_domains,
-                   trusted_domains_enabled,
-                   unix_root_sid,
-                   user_id_mapping_info,
-                   user_name,
-                   whitelisted_domains,
-                   workgroup)
-
-
+        return cls(
+            domain_name,
+            fallback_user_id_mapping_info,
+            force_remove,
+            ignored_trusted_domains,
+            ldap_provider_id,
+            machine_accounts,
+            only_use_whitelisted_domains,
+            ou_name,
+            password,
+            preferred_domain_controllers,
+            task_path,
+            tenant_id,
+            trusted_domains,
+            trusted_domains_enabled,
+            unix_root_sid,
+            user_id_mapping_info,
+            user_name,
+            whitelisted_domains,
+            workgroup
+)
\ No newline at end of file
