@@ -1,30 +1,29 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class ActiveDirectoryPrincipalsAddParameters(object):
 
     """Implementation of the 'ActiveDirectoryPrincipalsAddParameters' model.
 
-    Specifies the settings for adding new users and groups
-    for Active Directory principals.
-    These users and groups are added to the Cohesity Cluster.
-    You cannot create users and groups in the default Cohesity domain
-    called 'LOCAL' using this operation.
+    Specifies the settings for adding new users and groups for Active Directory
+    principals. These users and groups are added to the Cohesity Cluster. You
+    cannot create users and groups in the default Cohesity domain called
+    'LOCAL' using this operation.
+
 
     Attributes:
-        description (string): Specifies a description about the user or
-            group.
-        domain (string): Specifies the domain of the Active Directory where
-            the referenced principal is stored.
-        object_class (ObjectClassActiveDirectoryPrincipalsAddParametersEnum):
-            Specifies the type of the referenced Active Directory principal.
-            If 'kGroup', the referenced Active Directory principal is a group.
-            If 'kUser', the referenced Active Directory principal is a user.
-            'kUser' specifies a user object class. 'kGroup' specifies a group
-            object class. 'kComputer' specifies a computer object class.
-            'kWellKnownPrincipal' specifies a well known principal.
-            'kServiceAccount' specifies a service account object class.
+
+        description (string): Specifies a description about the user or group.
+        domain (string): Specifies the domain of the Active Directory where the
+            referenced principal is stored.
+        object_class (ObjectClassEnum): Specifies the type of the referenced
+            Active Directory principal. If 'kGroup', the referenced Active
+            Directory principal is a group. If 'kUser', the referenced Active
+            Directory principal is a user. 'kUser' specifies a user object
+            class. 'kGroup' specifies a group object class. 'kComputer'
+            specifies a computer object class. 'kWellKnownPrincipal' specifies
+            a well known principal. 'kServiceAccount' specifies a service
+            account object class.
         principal_name (string): Specifies the name of the Active Directory
             principal, that will be referenced by the group or user. The name
             of the Active Directory principal is used for naming the new group
@@ -40,9 +39,9 @@ class ActiveDirectoryPrincipalsAddParameters(object):
             associated with the Cohesity 'View' role, 'joe' can log in to the
             Cohesity Dashboard and has a read-only view of the data on the
             Cohesity Cluster.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "description":'description',
@@ -50,16 +49,17 @@ class ActiveDirectoryPrincipalsAddParameters(object):
         "object_class":'objectClass',
         "principal_name":'principalName',
         "restricted":'restricted',
-        "roles":'roles'
+        "roles":'roles',
     }
-
     def __init__(self,
                  description=None,
                  domain=None,
                  object_class=None,
                  principal_name=None,
                  restricted=None,
-                 roles=None):
+                 roles=None,
+            ):
+
         """Constructor for the ActiveDirectoryPrincipalsAddParameters class"""
 
         # Initialize members of the class
@@ -70,7 +70,6 @@ class ActiveDirectoryPrincipalsAddParameters(object):
         self.restricted = restricted
         self.roles = roles
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -94,14 +93,14 @@ class ActiveDirectoryPrincipalsAddParameters(object):
         object_class = dictionary.get('objectClass')
         principal_name = dictionary.get('principalName')
         restricted = dictionary.get('restricted')
-        roles = dictionary.get('roles')
+        roles = dictionary.get("roles")
 
         # Return an object of this model
-        return cls(description,
-                   domain,
-                   object_class,
-                   principal_name,
-                   restricted,
-                   roles)
-
-
+        return cls(
+            description,
+            domain,
+            object_class,
+            principal_name,
+            restricted,
+            roles
+)
\ No newline at end of file
