@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright 2023 Cohesity Inc.
 
-import cohesity_management_sdk.models.o365_region_proto
+import cohesity_management_sdk.models.o_365_region_proto
 import cohesity_management_sdk.models.registered_entity_sfdc_params
 
 
@@ -17,10 +17,10 @@ class AdditionalConnectorParams(object):
 
         max_vmware_http_sessions (int): Max http sessions per context for
             VMWare vAPI calls.
-        o365_emulator_entity_info (string): A token used only in O365 Emulator
+        o_365_emulator_entity_info (string): A token used only in O365 Emulator
             identifying the information of number of Users, Sites, Groups,
             Teams & Public Folders and their ids.
-        o365_region (O365RegionProto): Optional o365_region proto to store the
+        o_365_region (O365RegionProto): Optional o365_region proto to store the
             region info to be used while making ews/graph api calls in o365
             adapter.
         registered_entity_sfdc_params (RegisteredEntitySfdcParams):
@@ -40,16 +40,16 @@ class AdditionalConnectorParams(object):
     # Create a mapping from Model property names to API property names
     _names = {
         "max_vmware_http_sessions":'maxVmwareHttpSessions',
-        "o365_emulator_entity_info":'o365EmulatorEntityInfo',
-        "o365_region":'o365Region',
+        "o_365_emulator_entity_info":'o365EmulatorEntityInfo',
+        "o_365_region":'o365Region',
         "registered_entity_sfdc_params":'registeredEntitySfdcParams',
         "use_get_searchable_mailboxes_api":'useGetSearchableMailboxesApi',
         "use_outlook_ews_oauth":'useOutlookEwsOauth',
     }
     def __init__(self,
                  max_vmware_http_sessions=None,
-                 o365_emulator_entity_info=None,
-                 o365_region=None,
+                 o_365_emulator_entity_info=None,
+                 o_365_region=None,
                  registered_entity_sfdc_params=None,
                  use_get_searchable_mailboxes_api=None,
                  use_outlook_ews_oauth=None,
@@ -59,8 +59,8 @@ class AdditionalConnectorParams(object):
 
         # Initialize members of the class
         self.max_vmware_http_sessions = max_vmware_http_sessions
-        self.o365_emulator_entity_info = o365_emulator_entity_info
-        self.o365_region = o365_region
+        self.o_365_emulator_entity_info = o_365_emulator_entity_info
+        self.o_365_region = o_365_region
         self.registered_entity_sfdc_params = registered_entity_sfdc_params
         self.use_get_searchable_mailboxes_api = use_get_searchable_mailboxes_api
         self.use_outlook_ews_oauth = use_outlook_ews_oauth
@@ -84,8 +84,8 @@ class AdditionalConnectorParams(object):
 
         # Extract variables from the dictionary
         max_vmware_http_sessions = dictionary.get('maxVmwareHttpSessions')
-        o365_emulator_entity_info = dictionary.get('o365EmulatorEntityInfo')
-        o365_region = cohesity_management_sdk.models.o365_region_proto.O365RegionProto.from_dictionary(dictionary.get('o365Region')) if dictionary.get('o365Region') else None
+        o_365_emulator_entity_info = dictionary.get('o365EmulatorEntityInfo')
+        o_365_region = cohesity_management_sdk.models.o_365_region_proto.O365RegionProto.from_dictionary(dictionary.get('o365Region')) if dictionary.get('o365Region') else None
         registered_entity_sfdc_params = cohesity_management_sdk.models.registered_entity_sfdc_params.RegisteredEntitySfdcParams.from_dictionary(dictionary.get('registeredEntitySfdcParams')) if dictionary.get('registeredEntitySfdcParams') else None
         use_get_searchable_mailboxes_api = dictionary.get('useGetSearchableMailboxesApi')
         use_outlook_ews_oauth = dictionary.get('useOutlookEwsOauth')
@@ -93,8 +93,8 @@ class AdditionalConnectorParams(object):
         # Return an object of this model
         return cls(
             max_vmware_http_sessions,
-            o365_emulator_entity_info,
-            o365_region,
+            o_365_emulator_entity_info,
+            o_365_region,
             registered_entity_sfdc_params,
             use_get_searchable_mailboxes_api,
             use_outlook_ews_oauth
