@@ -1,73 +1,67 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.alert_document
 
+
 class AlertMetadata(object):
 
     """Implementation of the 'AlertMetadata' model.
 
     AlertMetadata specifies metadata for a given alert type. All the alerts of
-    a
-    given alert type share the same metadata.
+    a given alert type share the same metadata.
+
 
     Attributes:
+
         alert_document_list (list of AlertDocument): Specifies alert
             documentation one per each language supported.
         alert_type_bucket (AlertTypeBucketEnum): Specifies the Alert type
-            bucket.
-            Specifies the Alert type bucket.
-            kHardware - Alerts related to hardware on which Cohesity software
-            is running.
-            kSoftware - Alerts which are related to software components.
-            kDataService - Alerts related to data services.
-            kMaintenance - Alerts relates to maintenance activities.
+            bucket. Specifies the Alert type bucket. kHardware - Alerts related
+            to hardware on which Cohesity software is running. kSoftware -
+            Alerts which are related to software components. kDataService -
+            Alerts related to data services. kMaintenance - Alerts relates to
+            maintenance activities.
         alert_type_id (int): Specifies unique id for the alert type.
-        category (AlertCategoryEnum): Specifies category of the alert type.
-            Specifies the category of an Alert.
-            kDisk - Alert associated with the disk.
-            kNode - Alert associated with general hardware on a specific node.
-            kCluster - Alert associated with general hardware in cluster level.
-            kChassis - Alert associated with the Chassis.
-            kPowerSupply - Alert associated with the power supply.
-            kCPU - Alert associated with the CPU usage.
-            kMemory - Alert associated with the RAM/Memory.
-            kTemperature - Alert associated with the temperature.
-            kFan - Alert associated with the fan.
-            kNIC - Alert associated with network chips and interfaces.
-            kFirmware - Alert associated with the firmware.
-            kNodeHealth - Alert associated with node health status.
+        category (CategoryAlertMetadataEnum): Specifies category of the alert
+            type. Specifies the category of an Alert. kDisk - Alert associated
+            with the disk. kNode - Alert associated with general hardware on a
+            specific node. kCluster - Alert associated with general hardware in
+            cluster level. kChassis - Alert associated with the Chassis.
+            kPowerSupply - Alert associated with the power supply. kCPU - Alert
+            associated with the CPU usage. kMemory - Alert associated with the
+            RAM/Memory. kTemperature - Alert associated with the temperature.
+            kFan - Alert associated with the fan. kNIC - Alert associated with
+            network chips and interfaces. kFirmware - Alert associated with the
+            firmware. kNodeHealth - Alert associated with node health status.
             kOperatingSystem - Alert associated with operating systems.
             kDataPath - Alert associated with data management in the cluster.
-            kMetadata - Alert associated with metadata management.
-            kIndexing - Alert associated with indexing services.
-            kHelios - Alert associated with Helios.
-            kAppMarketPlace - Alert associated with App MarketPlace.
-            kLicense - Alert associated with licensing.
-            kSecurity - Alert associated with security.
-            kUpgrade - Alert associated with upgrade activities.
-            kClusterManagement - Alert associated with cluster management
-                activities.
-            kAuditLog - Alert associated with audit log events.
-            kNetworking - Alert associated with networking issue.
-            kConfiguration - Alert associated with cluster or system
-            configurations.
-            kStorageUsage - Alert associated with the disk/domain/cluster
-            storage usage.
-            kFaultTolerance - Alert associated with the fault tolerance in
-            different levels.
+            kMetadata - Alert associated with metadata management. kIndexing -
+            Alert associated with indexing services. kHelios - Alert associated
+            with Helios. kAppMarketPlace - Alert associated with App
+            MarketPlace. kLicense - Alert associated with licensing. kSecurity
+            - Alert associated with security. kUpgrade - Alert associated with
+            upgrade activities. kClusterManagement - Alert associated with
+            cluster management activities. kAuditLog - Alert associated with
+            audit log events. kNetworking - Alert associated with networking
+            issue. kConfiguration - Alert associated with cluster or system
+            configurations. kStorageUsage - Alert associated with the
+            disk/domain/cluster storage usage. kFaultTolerance - Alert
+            associated with the fault tolerance in different levels.
             kBackupRestore - Alert associated with Backup-Restore job.
             kArchivalRestore - Alert associated with Archival-Restore job.
-            kRemoteReplication - Alert associated with Replication job.
-            kQuota - Alert associated with Quotas.
-            kCDP - Alert associated with Continuous Data Protection.
+            kRemoteReplication - Alert associated with Replication job. kQuota
+            - Alert associated with Quotas. kCDP - Alert associated with
+            Continuous Data Protection. kViewFailover - Alert associated with
+            view Failover. kDisasterRecovery - Alert associated with Disaster
+            Recovery.
         dedup_interval_seconds (int): Specifies dedup interval in seconds. If
             the same alert is raised multiple times by any client in this
             duration, only one of them will be reported.
         dedup_until_resolved (bool): Specifies if the alerts are to be deduped
             until the current one (if any) is resolved.
-        hide_alert_from_user (bool): Specifies whether to show the alert in
-            the iris UI and CLI.
+        hide_alert_from_user (bool): Specifies whether to show the alert in the
+            iris UI and CLI.
         ignore_duplicate_occurrences (bool): Specifies whether to ignore
             duplicate occurrences completely.
         primary_key_list (list of string): Specifies properties that serve as
@@ -78,12 +72,12 @@ class AlertMetadata(object):
             notification for the alert.
         snmp_notification (bool): Specifies whether an SNMP notification is
             sent when an alert is raised.
-        syslog_notification (bool): Specifies whether an syslog notification
-            is sent when an alert is raised.
+        syslog_notification (bool): Specifies whether an syslog notification is
+            sent when an alert is raised.
         version (int): Specifies version of the metadata.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "alert_document_list":'alertDocumentList',
@@ -99,9 +93,8 @@ class AlertMetadata(object):
         "send_support_notification":'sendSupportNotification',
         "snmp_notification":'snmpNotification',
         "syslog_notification":'syslogNotification',
-        "version":'version'
+        "version":'version',
     }
-
     def __init__(self,
                  alert_document_list=None,
                  alert_type_bucket=None,
@@ -116,7 +109,9 @@ class AlertMetadata(object):
                  send_support_notification=None,
                  snmp_notification=None,
                  syslog_notification=None,
-                 version=None):
+                 version=None,
+            ):
+
         """Constructor for the AlertMetadata class"""
 
         # Initialize members of the class
@@ -135,7 +130,6 @@ class AlertMetadata(object):
         self.syslog_notification = syslog_notification
         self.version = version
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -166,27 +160,27 @@ class AlertMetadata(object):
         dedup_until_resolved = dictionary.get('dedupUntilResolved')
         hide_alert_from_user = dictionary.get('hideAlertFromUser')
         ignore_duplicate_occurrences = dictionary.get('ignoreDuplicateOccurrences')
-        primary_key_list = dictionary.get('primaryKeyList')
-        property_list = dictionary.get('propertyList')
+        primary_key_list = dictionary.get("primaryKeyList")
+        property_list = dictionary.get("propertyList")
         send_support_notification = dictionary.get('sendSupportNotification')
         snmp_notification = dictionary.get('snmpNotification')
         syslog_notification = dictionary.get('syslogNotification')
         version = dictionary.get('version')
 
         # Return an object of this model
-        return cls(alert_document_list,
-                   alert_type_bucket,
-                   alert_type_id,
-                   category,
-                   dedup_interval_seconds,
-                   dedup_until_resolved,
-                   hide_alert_from_user,
-                   ignore_duplicate_occurrences,
-                   primary_key_list,
-                   property_list,
-                   send_support_notification,
-                   snmp_notification,
-                   syslog_notification,
-                   version)
-
-
+        return cls(
+            alert_document_list,
+            alert_type_bucket,
+            alert_type_id,
+            category,
+            dedup_interval_seconds,
+            dedup_until_resolved,
+            hide_alert_from_user,
+            ignore_duplicate_occurrences,
+            primary_key_list,
+            property_list,
+            send_support_notification,
+            snmp_notification,
+            syslog_notification,
+            version
+)
\ No newline at end of file
