@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class AllocationMethodEnum(object):
 
     """Implementation of the 'AllocationMethod' enum.
+    Specifies the enum for IP allocation method. 'kUnknownAllocMethod'
+    indicates allocation method is unknown. 'kStaticAllocMethod' indicates
+    static allocation method for IP addresses. 'kDynamicAllocMethod' indicates
+    dynamic allocation method for IP addresses.
 
-    Specifies the enum for IP allocation method.
-    'kUnknownAllocMethod' indicates allocation method is unknown.
-    'kStaticAllocMethod' indicates static allocation method for IP addresses.
-    'kDynamicAllocMethod' indicates dynamic allocation method for IP addresses.
 
     Attributes:
         KUNKNOWNALLOCMETHOD: TODO: type description here.
@@ -16,9 +16,9 @@ class AllocationMethodEnum(object):
         KDYNAMICALLOCMETHOD: TODO: type description here.
 
     """
+
     KUNKNOWNALLOCMETHOD = 'kUnknownAllocMethod'
 
     KSTATICALLOCMETHOD = 'kStaticAllocMethod'
 
     KDYNAMICALLOCMETHOD = 'kDynamicAllocMethod'
-
