@@ -13,8 +13,8 @@ class AntivirusServiceConfig(object):
         description (string): Specifies the description of the Antivirus
             service. This could be any additional information admin might
             associate with the Antivirus service.
-        icap_uri (string): Specifies the ICAP uri for this Antivirus service.
-            It is of the form icap://<ip-address>[:<port>]/<service>
+        icap_uri (string, required): Specifies the ICAP uri for this Antivirus
+            service. It is of the form icap://<ip-address>[:<port>]/<service>
         tag (string): Specifies the tag of antivirus service. This is
             service-specific "cookie" sent from Antivirus server to clients
             that represents a service's current state. This tag validates that
