@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class ApiKey(object):
 
@@ -8,15 +7,17 @@ class ApiKey(object):
 
     Specifies the parameters of an API key.
 
+
     Attributes:
-        created_time_msecs (int|long): Specifies the API key created time in
+
+        created_time_msecs (long|int): Specifies the API key created time in
             milli seconds.
         created_user_sid (string): Specifies the user sid who created this API
             key.
         created_username (string): Specifies the username who created this API
             key.
-        expiring_time_msecs (long|int): Specifies a time stamp when the API
-            key will expire in milli seconds.
+        expiring_time_msecs (long|int): Specifies a time stamp when the API key
+            will expire in milli seconds.
         id (string): Specifies the API key id.
         is_active (bool): Specifies if the API key is active. Only an active
             and not expired API key can be used for authentication.
@@ -25,9 +26,9 @@ class ApiKey(object):
         name (string): Specifies the API key name.
         owner_user_sid (string): Specifies the user sid who owns this API key.
         owner_username (string): Specifies the username who owns this API key.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "created_time_msecs":'createdTimeMsecs',
@@ -39,9 +40,8 @@ class ApiKey(object):
         "is_expired":'isExpired',
         "name":'name',
         "owner_user_sid":'ownerUserSid',
-        "owner_username":'ownerUsername'
+        "owner_username":'ownerUsername',
     }
-
     def __init__(self,
                  created_time_msecs=None,
                  created_user_sid=None,
@@ -52,7 +52,9 @@ class ApiKey(object):
                  is_expired=None,
                  name=None,
                  owner_user_sid=None,
-                 owner_username=None):
+                 owner_username=None,
+            ):
+
         """Constructor for the ApiKey class"""
 
         # Initialize members of the class
@@ -67,7 +69,6 @@ class ApiKey(object):
         self.owner_user_sid = owner_user_sid
         self.owner_username = owner_username
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -98,15 +99,15 @@ class ApiKey(object):
         owner_username = dictionary.get('ownerUsername')
 
         # Return an object of this model
-        return cls(created_time_msecs,
-                   created_user_sid,
-                   created_username,
-                   expiring_time_msecs,
-                   id,
-                   is_active,
-                   is_expired,
-                   name,
-                   owner_user_sid,
-                   owner_username)
-
-
+        return cls(
+            created_time_msecs,
+            created_user_sid,
+            created_username,
+            expiring_time_msecs,
+            id,
+            is_active,
+            is_expired,
+            name,
+            owner_user_sid,
+            owner_username
+)
\ No newline at end of file
