@@ -1,14 +1,13 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class AuthTypeEnum(object):
 
     """Implementation of the 'AuthType' enum.
-
     Specifies the authentication type used while connecting to LDAP servers.
-    Authentication level.
-    'kAnonymous' indicates LDAP authentication type 'Anonymous'
-    'kSimple' indicates LDAP authentication type 'Simple'
+    Authentication level. 'kAnonymous' indicates LDAP authentication type
+    'Anonymous' 'kSimple' indicates LDAP authentication type 'Simple'
+
 
     Attributes:
         KANONYMOUS: TODO: type description here.
@@ -19,4 +18,3 @@ class AuthTypeEnum(object):
     KANONYMOUS = 'kAnonymous'
 
     KSIMPLE = 'kSimple'
-
