@@ -1,30 +1,36 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.ebs_volume_exclusion_params
 
+
 class AWSSnapshotManagerBackupSourceParams(object):
 
     """Implementation of the 'AWSSnapshotManagerBackupSourceParams' model.
 
+    TODO: type description here.
+
+
     Attributes:
-        volume_exclusion_params (EBSVolumeExclusionParams): Specifies the different
-        criteria to exclude volumes from backup.
+
+        volume_exclusion_params (EBSVolumeExclusionParams): Specifies the
+            different criteria to exclude volumes from backup.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "volume_exclusion_params":'volumeExclusionParams'
+        "volume_exclusion_params":'volumeExclusionParams',
     }
-
     def __init__(self,
-                 volume_exclusion_params=None):
+                 volume_exclusion_params=None,
+            ):
+
         """Constructor for the AWSSnapshotManagerBackupSourceParams class"""
 
         # Initialize members of the class
         self.volume_exclusion_params = volume_exclusion_params
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -46,6 +52,6 @@ class AWSSnapshotManagerBackupSourceParams(object):
         volume_exclusion_params = cohesity_management_sdk.models.ebs_volume_exclusion_params.EBSVolumeExclusionParams.from_dictionary(dictionary.get('volumeExclusionParams')) if dictionary.get('volumeExclusionParams') else None
 
         # Return an object of this model
-        return cls(volume_exclusion_params)
-
-
+        return cls(
+            volume_exclusion_params
+)
\ No newline at end of file
