@@ -1,37 +1,38 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class BackupJobProto_RemoteViewParams_RemoteViewParamsPerView(object):
 
     """Implementation of the 'BackupJobProto_RemoteViewParams_RemoteViewParamsPerView' model.
 
-    IP Range for range of vip address addition.
+    TODO: type description here.
+
 
     Attributes:
+
         remote_view_name (string): If 'use_same_name_as_source_view' is false,
             below name should be populated.
         use_same_name_as_source_view (bool): Whether remote view name will be
             same as the source view name.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "remote_view_name": 'remoteViewName',
-        "use_same_name_as_source_view": 'useSameNameAsSourceView'
+        "remote_view_name":'remoteViewName',
+        "use_same_name_as_source_view":'useSameNameAsSourceView',
     }
-
     def __init__(self,
                  remote_view_name=None,
-                 use_same_name_as_source_view=None):
+                 use_same_name_as_source_view=None,
+            ):
+
         """Constructor for the BackupJobProto_RemoteViewParams_RemoteViewParamsPerView class"""
 
         # Initialize members of the class
         self.remote_view_name = remote_view_name
         self.use_same_name_as_source_view = use_same_name_as_source_view
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -50,11 +51,11 @@ class BackupJobProto_RemoteViewParams_RemoteViewParamsPerView(object):
             return None
 
         # Extract variables from the dictionary
-        remote_view_name = dictionary.get('remoteViewName', None)
-        use_same_name_as_source_view = dictionary.get('useSameNameAsSourceView', None)
+        remote_view_name = dictionary.get('remoteViewName')
+        use_same_name_as_source_view = dictionary.get('useSameNameAsSourceView')
 
         # Return an object of this model
-        return cls(remote_view_name,
-                   use_same_name_as_source_view)
-
-
+        return cls(
+            remote_view_name,
+            use_same_name_as_source_view
+)
\ No newline at end of file
