@@ -1,16 +1,21 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.bandwidth_limit_override
 
+
 class BandwidthLimit(object):
 
     """Implementation of the 'BandwidthLimit' model.
 
-    Specifies settings for limiting the data transfer rate between
-    the local and remote Clusters.
+    Specifies settings for limiting the data transfer rate between the local
+    and remote Clusters or bandwidth limiting schedule for apollo. Only one of
+    RateLimitBytesPerSec or IoRate should be set in this struct and
+    corresponding BandwidthLimitOverrides should also be in the same unit.
+
 
     Attributes:
+
         bandwidth_limit_overrides (list of BandwidthLimitOverride): Array of
             Override Bandwidth Limits.  Specifies a list of override bandwidth
             limits and time periods when those limits override the
@@ -19,29 +24,30 @@ class BandwidthLimit(object):
         io_rate (int): Specifies the default IO Rate of the throttling
             schedule. This value is internally mapped to some notion of how
             many resources a process should be consuming.
-        rate_limit_bytes_per_sec (long|int): Specifies the maximum allowed
-            data transfer rate between the local Cluster and remote Clusters.
-            The value is specified in bytes per second. If not set, the data
+        rate_limit_bytes_per_sec (long|int): Specifies the maximum allowed data
+            transfer rate between the local Cluster and remote Clusters. The
+            value is specified in bytes per second. If not set, the data
             transfer rate is not limited.
-        timezone (string): Specifies a time zone for the specified time
-            period. The time zone is defined in the following format:
-            "Area/Location", for example: "America/New_York".
-
+        timezone (string): Specifies a time zone for the specified time period.
+            The time zone is defined in the following format: "Area/Location",
+            for example: "America/New_York".
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "bandwidth_limit_overrides":'bandwidthLimitOverrides',
         "io_rate":'ioRate',
         "rate_limit_bytes_per_sec":'rateLimitBytesPerSec',
-        "timezone":'timezone'
+        "timezone":'timezone',
     }
-
     def __init__(self,
                  bandwidth_limit_overrides=None,
                  io_rate=None,
                  rate_limit_bytes_per_sec=None,
-                 timezone=None):
+                 timezone=None,
+            ):
+
         """Constructor for the BandwidthLimit class"""
 
         # Initialize members of the class
@@ -50,7 +56,6 @@ class BandwidthLimit(object):
         self.rate_limit_bytes_per_sec = rate_limit_bytes_per_sec
         self.timezone = timezone
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -74,14 +79,14 @@ class BandwidthLimit(object):
             bandwidth_limit_overrides = list()
             for structure in dictionary.get('bandwidthLimitOverrides'):
                 bandwidth_limit_overrides.append(cohesity_management_sdk.models.bandwidth_limit_override.BandwidthLimitOverride.from_dictionary(structure))
-        rate_limit_bytes_per_sec = dictionary.get('rateLimitBytesPerSec')
         io_rate = dictionary.get('ioRate')
+        rate_limit_bytes_per_sec = dictionary.get('rateLimitBytesPerSec')
         timezone = dictionary.get('timezone')
 
         # Return an object of this model
-        return cls(bandwidth_limit_overrides,
-                   io_rate,
-                   rate_limit_bytes_per_sec,
-                   timezone)
-
-
+        return cls(
+            bandwidth_limit_overrides,
+            io_rate,
+            rate_limit_bytes_per_sec,
+            timezone
+)
\ No newline at end of file
