@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.bifrost_subnet
 
+
 class BifrostConfig(object):
 
     """Implementation of the 'BifrostConfig' model.
@@ -10,35 +11,29 @@ class BifrostConfig(object):
     Specifies the settings of a BifrostConfig. Its used by both Request and
     Response structures.
 
+
     Attributes:
+
         image_version (string): Specifies the bifrost image version.
         cpu (int): Specifies the cpu for the bifrost config.
         description (string): Specifies a description of the VLAN.
         id (int): Specifies the id of the VLAN tag.
-        iface_group_name (string): Specifies the interface group name of the VLAN. It
-            is in the format of <base_interface_group_name>.<vlan_id>.
+        iface_group_name (string): Specifies the interface group name of the
+            VLAN. It is in the format of <base_interface_group_name>.<vlan_id>.
         memory (int): Specifies the memory for the bifrost config.
         mtu (int): Specifies the mtu for the bifrost vlan.
-        state (string): 4 types of States
-            UNKNOWN
-            ACTIVE
-            DISABLED
-            DELETING
-        subnet (BifrostSubnet): Specifies the subnet of the VLAN.
-            The netmask can be specified by setting netmaskBits or netmaskIp4.
-            The netmask can only be set using netmaskIp4 if the IP address is
-            an IPv4 address. It can carry V4 or V6 in case of requests, and
-            carries V4 in case of response.
+        state (string): 4 types of States UNKNOWN ACTIVE DISABLED DELETING
+        subnet (BifrostSubnet): Specifies the subnet of the VLAN. The netmask
+            can be specified by setting netmaskBits or netmaskIp4. The netmask
+            can only be set using netmaskIp4 if the IP address is an IPv4
+            address. It can carry V4 or V6 in case of requests, and carries V4
+            in case of response.
         tenant_id (string): Specifies the tenant id that this vlan belongs to.
-            mcm-on-prem-mode. If set to true, it is in mcm on prem mode. This
-            need mcm-mode to be true.
-        mtype (string): Two types of bifrost vlans.
-            INTERNAL
-            EXTERNAL
+        mtype (string): Two types of bifrost vlans. INTERNAL EXTERNAL
         vlan_name (string): Specifies the VLAN name of the vlanId.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "image_version":'ImageVersion',
@@ -52,9 +47,8 @@ class BifrostConfig(object):
         "subnet":'subnet',
         "tenant_id":'tenantId',
         "mtype":'type',
-        "vlan_name":'vlanName'
+        "vlan_name":'vlanName',
     }
-
     def __init__(self,
                  image_version=None,
                  cpu=None,
@@ -67,7 +61,9 @@ class BifrostConfig(object):
                  subnet=None,
                  tenant_id=None,
                  mtype=None,
-                 vlan_name=None):
+                 vlan_name=None,
+            ):
+
         """Constructor for the BifrostConfig class"""
 
         # Initialize members of the class
@@ -84,7 +80,6 @@ class BifrostConfig(object):
         self.mtype = mtype
         self.vlan_name = vlan_name
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -117,17 +112,17 @@ class BifrostConfig(object):
         vlan_name = dictionary.get('vlanName')
 
         # Return an object of this model
-        return cls(image_version,
-                   cpu,
-                   description,
-                   id,
-                   iface_group_name,
-                   memory,
-                   mtu,
-                   state,
-                   subnet,
-                   tenant_id,
-                   mtype,
-                   vlan_name)
-
-
+        return cls(
+            image_version,
+            cpu,
+            description,
+            id,
+            iface_group_name,
+            memory,
+            mtu,
+            state,
+            subnet,
+            tenant_id,
+            mtype,
+            vlan_name
+)
\ No newline at end of file
