@@ -1,43 +1,47 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.time_of_day
 
+
 class BlackoutPeriod(object):
 
     """Implementation of the 'BlackoutPeriod' model.
 
-    Specifies a time range in a single day when new Job Runs of
-    Protection Jobs cannot be started. For example, a Protection Job
-    with a daily schedule could define a blackout period for Sunday.
+    Specifies a time range in a single day when new Job Runs of Protection Jobs
+    cannot be started. For example, a Protection Job with a daily schedule
+    could define a QuietTime period for Sunday.
+
 
     Attributes:
+
         id (string): Specified the Id for a snapshot copy policy. This is
             generated when the policy is created.
-        day (DayBlackoutPeriodEnum): Blackout Day.  Specifies a day in the
-            week when no new Job Runs should be started such as 'kSunday'. If
-            not set, the time range applies to all days. Specifies a day in a
-            week such as 'kSunday', 'kMonday', etc.
-        end_time (TimeOfDay): Specifies the end time of the blackout time
+        day (DayEnum): QuietTime Day.  Specifies a day in the week when no new
+            Job Runs should be started such as 'kSunday'. If not set, the time
+            range applies to all days. Specifies a day in a week such as
+            'kSunday', 'kMonday', etc.
+        end_time (TimeOfDay): Specifies the end time of the QuietTime time
             range.
-        start_time (TimeOfDay): Specifies the start time of the blackout time
+        start_time (TimeOfDay): Specifies the start time of the QuietTime time
             range.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "id":'Id',
         "day":'day',
         "end_time":'endTime',
-        "start_time":'startTime'
+        "start_time":'startTime',
     }
-
     def __init__(self,
                  id=None,
                  day=None,
                  end_time=None,
-                 start_time=None):
+                 start_time=None,
+            ):
+
         """Constructor for the BlackoutPeriod class"""
 
         # Initialize members of the class
@@ -46,7 +50,6 @@ class BlackoutPeriod(object):
         self.end_time = end_time
         self.start_time = start_time
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -71,9 +74,9 @@ class BlackoutPeriod(object):
         start_time = cohesity_management_sdk.models.time_of_day.TimeOfDay.from_dictionary(dictionary.get('startTime')) if dictionary.get('startTime') else None
 
         # Return an object of this model
-        return cls(id,
-                   day,
-                   end_time,
-                   start_time)
-
-
+        return cls(
+            id,
+            day,
+            end_time,
+            start_time
+)
\ No newline at end of file
