@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class CdpIoFilterState(object):
 
@@ -9,32 +8,34 @@ class CdpIoFilterState(object):
     CdpIoFilterState specifies the current state of the CDP IO Filter for a
     single Protection Source.
 
+
     Attributes:
+
         error_message (string): Specifies the message of the error, which was
             encountered duing the last upgrade. If this is specified, then it
             means that the last upgrade failed.
         filter_status (string): Specifies the current status of the IO Filter.
-          See magneto/base/entities.proto > IgrOFilterState > FilterStatus
+            See magneto/base/entities.proto > IOFilterState > FilterStatus
         upgradability (string): Specifies the current upgradability status of
-            the IO Filter.
-            See magneto/base/common.proto > Upgradability
+            the IO Filter. See magneto/base/common.proto > Upgradability
         version (string): Specifies the current version of the IO filter.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "error_message":'errorMessage',
         "filter_status":'filterStatus',
         "upgradability":'upgradability',
-        "version":'version'
+        "version":'version',
     }
-
     def __init__(self,
                  error_message=None,
                  filter_status=None,
                  upgradability=None,
-                 version=None):
+                 version=None,
+            ):
+
         """Constructor for the CdpIoFilterState class"""
 
         # Initialize members of the class
@@ -43,7 +44,6 @@ class CdpIoFilterState(object):
         self.upgradability = upgradability
         self.version = version
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -68,9 +68,9 @@ class CdpIoFilterState(object):
         version = dictionary.get('version')
 
         # Return an object of this model
-        return cls(error_message,
-                   filter_status,
-                   upgradability,
-                   version)
-
-
+        return cls(
+            error_message,
+            filter_status,
+            upgradability,
+            version
+)
\ No newline at end of file
