@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class ChassisInfo(object):
 
@@ -8,7 +7,9 @@ class ChassisInfo(object):
 
     ChassisInfo is the struct for the Chassis.
 
+
     Attributes:
+
         chassis_id (long|int): ChassisId is a unique id assigned to the
             chassis.
         chassis_name (string): ChassisName is the name of the chassis. This
@@ -17,24 +18,25 @@ class ChassisInfo(object):
         location (string): Location is the location of the chassis within the
             rack.
         rack_id (long|int): Rack is the rack within which this chassis lives.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "chassis_id":'chassisId',
         "chassis_name":'chassisName',
         "chassis_serial":'chassisSerial',
         "location":'location',
-        "rack_id":'rackId'
+        "rack_id":'rackId',
     }
-
     def __init__(self,
                  chassis_id=None,
                  chassis_name=None,
                  chassis_serial=None,
                  location=None,
-                 rack_id=None):
+                 rack_id=None,
+            ):
+
         """Constructor for the ChassisInfo class"""
 
         # Initialize members of the class
@@ -44,7 +46,6 @@ class ChassisInfo(object):
         self.location = location
         self.rack_id = rack_id
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -70,10 +71,10 @@ class ChassisInfo(object):
         rack_id = dictionary.get('rackId')
 
         # Return an object of this model
-        return cls(chassis_id,
-                   chassis_name,
-                   chassis_serial,
-                   location,
-                   rack_id)
-
-
+        return cls(
+            chassis_id,
+            chassis_name,
+            chassis_serial,
+            location,
+            rack_id
+)
\ No newline at end of file
