@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class CloneAppViewInfoOracle(object):
 
@@ -9,24 +8,26 @@ class CloneAppViewInfoOracle(object):
     This message encapsulates backup view Clone operation information of a
     Oracle DB.
 
-    Attributes:
-        mount_path_info_vec (list of string): TODO: type description here.
 
+    Attributes:
+
+        mount_path_info_vec (list of string): TODO: Type description here.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "mount_path_info_vec":'mountPathInfoVec'
+        "mount_path_info_vec":'mountPathInfoVec',
     }
-
     def __init__(self,
-                 mount_path_info_vec=None):
+                 mount_path_info_vec=None,
+            ):
+
         """Constructor for the CloneAppViewInfoOracle class"""
 
         # Initialize members of the class
         self.mount_path_info_vec = mount_path_info_vec
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -45,9 +46,9 @@ class CloneAppViewInfoOracle(object):
             return None
 
         # Extract variables from the dictionary
-        mount_path_info_vec = dictionary.get('mountPathInfoVec')
+        mount_path_info_vec = dictionary.get("mountPathInfoVec")
 
         # Return an object of this model
-        return cls(mount_path_info_vec)
-
-
+        return cls(
+            mount_path_info_vec
+)
\ No newline at end of file
