@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class CloneTaskInfo(object):
 
@@ -8,28 +7,30 @@ class CloneTaskInfo(object):
 
     Parameters for a clone op.
 
+
     Attributes:
+
         name (string): Name of the recovery task.
         task_id (string): Id of the recovery task.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "name":'name',
-        "task_id":'taskId'
+        "task_id":'taskId',
     }
-
     def __init__(self,
                  name=None,
-                 task_id=None):
+                 task_id=None,
+            ):
+
         """Constructor for the CloneTaskInfo class"""
 
         # Initialize members of the class
         self.name = name
         self.task_id = task_id
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -52,7 +53,7 @@ class CloneTaskInfo(object):
         task_id = dictionary.get('taskId')
 
         # Return an object of this model
-        return cls(name,
-                   task_id)
-
-
+        return cls(
+            name,
+            task_id
+)
\ No newline at end of file
