@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.quota_policy
 
+
 class CloudArchivalDirectConfig(object):
 
     """Implementation of the 'CloudArchivalDirectConfig' model.
@@ -10,32 +11,32 @@ class CloudArchivalDirectConfig(object):
     CloudArchivalDirectConfig specifies the properties of vaults used to
     perform Cloud Archive Direct (CAD)
 
+
     Attributes:
+
         bucket_namesapce (string): Specifies a namespace under the bucket used
             for archival.
         physical_quota (QuotaPolicy): Specifies quota limit in bytes for
-            physical usage associated with this vault during the first CAD
-            job.
-
-
+            physical usage associated with this vault during the first CAD job.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "bucket_namesapce": 'bucketNamesapce',
-        "physical_quota": 'physicalQuota'
+        "bucket_namesapce":'bucketNamesapce',
+        "physical_quota":'physicalQuota',
     }
-
     def __init__(self,
                  bucket_namesapce=None,
-                 physical_quota=None):
+                 physical_quota=None,
+            ):
+
         """Constructor for the CloudArchivalDirectConfig class"""
 
         # Initialize members of the class
         self.bucket_namesapce = bucket_namesapce
         self.physical_quota = physical_quota
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -58,7 +59,7 @@ class CloudArchivalDirectConfig(object):
         physical_quota = cohesity_management_sdk.models.quota_policy.QuotaPolicy.from_dictionary(dictionary.get('physicalQuota')) if dictionary.get('physicalQuota') else None
 
         # Return an object of this model
-        return cls(bucket_namesapce,
-                   physical_quota)
-
-
+        return cls(
+            bucket_namesapce,
+            physical_quota
+)
\ No newline at end of file
