@@ -1,45 +1,51 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.cluster_config_proto_vault_cloud_properties_amazon_properties
 import cohesity_management_sdk.models.cluster_config_proto_vault_cloud_properties_azure_properties
 import cohesity_management_sdk.models.cluster_config_proto_vault_cloud_properties_google_properties
 import cohesity_management_sdk.models.cluster_config_proto_vault_cloud_properties_oracle_properties
 
+
 class ClusterConfigProto_Vault_CloudProperties(object):
 
     """Implementation of the 'ClusterConfigProto_Vault_CloudProperties' model.
 
-    The following represents the cloud properties proto which handles
-    different properties supported by different cloud providers.
+    The following represents the cloud properties proto which handles different
+    properties supported by different cloud providers.
+
 
     Attributes:
-        amazon_properties (
-            ClusterConfigProto_Vault_CloudProperties_AmazonProperties):
-            TODO: Type description here.
-        azure_properties (
-            ClusterConfigProto_Vault_CloudProperties_AzureProperties):
-            TODO: Type description here.
-        google_properties (ClusterConfigProto_Vault_CloudProperties_GoogleProperties):
-            TODO: Type description here.
-        oracle_properties (ClusterConfigProto_Vault_CloudProperties_OracleProperties):
-            TODO: Type description here.
 
+        amazon_properties
+            (ClusterConfigProto_Vault_CloudProperties_AmazonProperties): TODO:
+            Type description here.
+        azure_properties
+            (ClusterConfigProto_Vault_CloudProperties_AzureProperties): TODO:
+            Type description here.
+        google_properties
+            (ClusterConfigProto_Vault_CloudProperties_GoogleProperties): TODO:
+            Type description here.
+        oracle_properties
+            (ClusterConfigProto_Vault_CloudProperties_OracleProperties): TODO:
+            Type description here.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "amazon_properties":'amazonProperties',
         "azure_properties":'azureProperties',
         "google_properties":'googleProperties',
-        "oracle_properties":'oracleProperties'
+        "oracle_properties":'oracleProperties',
     }
-
     def __init__(self,
                  amazon_properties=None,
                  azure_properties=None,
                  google_properties=None,
-                 oracle_properties=None):
+                 oracle_properties=None,
+            ):
+
         """Constructor for the ClusterConfigProto_Vault_CloudProperties class"""
 
         # Initialize members of the class
@@ -48,7 +54,6 @@ class ClusterConfigProto_Vault_CloudProperties(object):
         self.google_properties = google_properties
         self.oracle_properties = oracle_properties
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -73,9 +78,9 @@ class ClusterConfigProto_Vault_CloudProperties(object):
         oracle_properties = cohesity_management_sdk.models.cluster_config_proto_vault_cloud_properties_oracle_properties.ClusterConfigProto_Vault_CloudProperties_OracleProperties.from_dictionary(dictionary.get('oracleProperties')) if dictionary.get('oracleProperties') else None
 
         # Return an object of this model
-        return cls(amazon_properties,
-                   azure_properties,
-                   google_properties,
-                   oracle_properties)
-
-
+        return cls(
+            amazon_properties,
+            azure_properties,
+            google_properties,
+            oracle_properties
+)
\ No newline at end of file
