@@ -1,33 +1,37 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class ClusterConfigProto_Vault_CloudProperties_OracleProperties(object):
 
     """Implementation of the 'ClusterConfigProto_Vault_CloudProperties_OracleProperties' model.
 
-    Attributes:
-        tenant (string): Tenant part of the REST endpoints for Oracle S3 compatible vaults.
-        tier_type (int): TODO: Type description here.
+    TODO: type description here.
 
+
+    Attributes:
+
+        tenant (string): Tenant part of the REST endpoints for Oracle S3
+            compatible vaults.
+        tier_type (int): TODO: Type description here.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "tenant": 'tenant',
-        "tier_type": 'tierType'
+        "tenant":'tenant',
+        "tier_type":'tierType',
     }
-
     def __init__(self,
                  tenant=None,
-                 tier_type=None):
+                 tier_type=None,
+            ):
+
         """Constructor for the ClusterConfigProto_Vault_CloudProperties_OracleProperties class"""
 
         # Initialize members of the class
         self.tenant = tenant
         self.tier_type = tier_type
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -46,11 +50,11 @@ class ClusterConfigProto_Vault_CloudProperties_OracleProperties(object):
             return None
 
         # Extract variables from the dictionary
-        tenant = dictionary.get('tenant', None)
-        tier_type = dictionary.get('tierType', None)
+        tenant = dictionary.get('tenant')
+        tier_type = dictionary.get('tierType')
 
         # Return an object of this model
-        return cls(tenant,
-                   tier_type)
-
-
+        return cls(
+            tenant,
+            tier_type
+)
\ No newline at end of file
