@@ -1,29 +1,28 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class CouchbaseBackupJobParams(object):
 
     """Implementation of the 'CouchbaseBackupJobParams' model.
 
-    Contains any additional couchbase environment specific backup params at
-    the
+    Contains any additional couchbase environment specific backup params at the
     job level.
 
+
     Attributes:
 
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
     }
+    def __init__(self,
+            ):
 
-    def __init__(self):
         """Constructor for the CouchbaseBackupJobParams class"""
 
         # Initialize members of the class
-        pass
-
 
     @classmethod
     def from_dictionary(cls,
@@ -43,9 +42,8 @@ class CouchbaseBackupJobParams(object):
             return None
 
         # Extract variables from the dictionary
-        # TODO: add description here.
 
         # Return an object of this model
-        return cls()
-
+        return cls(
 
+)
\ No newline at end of file
