@@ -1,19 +1,16 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class DatabaseStateEnum(object):
 
     """Implementation of the 'DatabaseState' enum.
-
-    Specifies the state of the Exchange database copy.
-    Specifies the state of Exchange Database Copy.
-
-
-    'kUnknown' indicates the status is not known.
+    Specifies the state of the Exchange database copy. Specifies the state of
+    Exchange Database Copy.   'kUnknown' indicates the status is not known.
     'kMounted' indicates the exchange database copy is mounted and healthy.
     'kError' indicates  the  exchange  database  copy  is unmounted or
     partially mounted or is in error state.
 
+
     Attributes:
         KUNKNOWN: TODO: type description here.
         KMOUNTED: TODO: type description here.
@@ -26,4 +23,3 @@ class DatabaseStateEnum(object):
     KMOUNTED = 'kMounted'
 
     KERROR = 'kError'
-
