@@ -1,16 +1,15 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class DiskFormatEnum(object):
 
     """Implementation of the 'DiskFormat' enum.
+    Specifies the format of the virtual disk. 'kVMDK' indicates VMware's
+    Virtual Disk format. 'kVHD' indicates Microsoft's Virtual Hard Drive
+    format. 'kVHDx' indicates Microsoft's Hyper-V Virtual Hard Drive format.
+    'kRaw' indicates Raw disk format used by KVM, Acropolis. 'kUnknow'
+    indicates Unknown disk format.
 
-    Specifies the format of the virtual disk.
-    'kVMDK' indicates VMware's Virtual Disk format.
-    'kVHD' indicates Microsoft's Virtual Hard Drive format.
-    'kVHDx' indicates Microsoft's Hyper-V Virtual Hard Drive format.
-    'kRaw' indicates Raw disk format used by KVM, Acropolis.
-    'kUnknow' indicates Unknown disk format.
 
     Attributes:
         KVMDK: TODO: type description here.
@@ -30,4 +29,3 @@ class DiskFormatEnum(object):
     KRAW = 'kRaw'
 
     KUNKNOWN = 'kUnknown'
-
