@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class EnvironmentListProtectedObjectsEnum(object):
 
@@ -8,8 +8,8 @@ class EnvironmentListProtectedObjectsEnum(object):
     TODO: type enum description here.
 
     Attributes:
-        KVMWARE: TODO: type description here.
-        KHYPERV: TODO: type description here.
+        K_VMWARE: TODO: type description here.
+        K_HYPERV: TODO: type description here.
         KSQL: TODO: type description here.
         KVIEW: TODO: type description here.
         KPUPPETEER: TODO: type description here.
@@ -27,7 +27,7 @@ class EnvironmentListProtectedObjectsEnum(object):
         KKVM: TODO: type description here.
         KAWS: TODO: type description here.
         KEXCHANGE: TODO: type description here.
-        KHYPERVVSS: TODO: type description here.
+        K_HYPERV_VSS: TODO: type description here.
         KORACLE: TODO: type description here.
         KGCP: TODO: type description here.
         KFLASHBLADE: TODO: type description here.
@@ -48,7 +48,12 @@ class EnvironmentListProtectedObjectsEnum(object):
         KHIVE: TODO: type description here.
         KHBASE: TODO: type description here.
         KUDA: TODO: type description here.
-
+        KO365TEAMS: TODO: type description here.
+        KO365GROUP: TODO: type description here.
+        KO365EXCHANGE: TODO: type description here.
+        KO365ONEDRIVE: TODO: type description here.
+        KO365SHAREPOINT: TODO: type description here.
+        KO365PUBLICFOLDERS: TODO: type description here.
 
     """
 
@@ -132,4 +137,15 @@ class EnvironmentListProtectedObjectsEnum(object):
 
     KUDA = 'kUDA'
 
+    KO365TEAMS = 'kO365Teams'
+
+    KO365GROUP = 'kO365Group'
+
+    KO365EXCHANGE = 'kO365Exchange'
+
+    KO365ONEDRIVE = 'kO365OneDrive'
+
+    KO365SHAREPOINT = 'kO365Sharepoint'
+
+    KO365PUBLICFOLDERS = 'kO365PublicFolders'
 
