@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class EnvironmentSearchProtectionSourcesEnum(object):
 
@@ -7,6 +7,7 @@ class EnvironmentSearchProtectionSourcesEnum(object):
 
     TODO: type enum description here.
 
+
     Attributes:
         KVMWARE: TODO: type description here.
         KHYPERV: TODO: type description here.
@@ -48,7 +49,12 @@ class EnvironmentSearchProtectionSourcesEnum(object):
         KHIVE: TODO: type description here.
         KHBASE: TODO: type description here.
         KUDA: TODO: type description here.
-
+        KO365TEAMS: TODO: type description here.
+        KO365GROUP: TODO: type description here.
+        KO365EXCHANGE: TODO: type description here.
+        KO365ONEDRIVE: TODO: type description here.
+        KO365SHAREPOINT: TODO: type description here.
+        KO365PUBLICFOLDERS: TODO: type description here.
 
     """
 
@@ -131,3 +137,15 @@ class EnvironmentSearchProtectionSourcesEnum(object):
     KHBASE = 'kHBase'
 
     KUDA = 'kUDA'
+
+    KO365TEAMS = 'kO365Teams'
+
+    KO365GROUP = 'kO365Group'
+
+    KO365EXCHANGE = 'kO365Exchange'
+
+    KO365ONEDRIVE = 'kO365OneDrive'
+
+    KO365SHAREPOINT = 'kO365Sharepoint'
+
+    KO365PUBLICFOLDERS = 'kO365PublicFolders'
