@@ -1,31 +1,33 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class FeatureUsage(object):
 
     """Implementation of the 'FeatureUsage' model.
 
-    Structure to hold feature usage on cluster side.
+    TODO: type description here.
+
 
     Attributes:
+
         current_usage_gib (long|int): Feature usage by the cluster.
         feature_name (string): Name of feature.
         num_vm (long|int): Number of VM spinned.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "current_usage_gib":'currentUsageGiB',
         "feature_name":'featureName',
-        "num_vm":'numVm'
+        "num_vm":'numVm',
     }
-
     def __init__(self,
                  current_usage_gib=None,
                  feature_name=None,
-                 num_vm=None):
+                 num_vm=None,
+            ):
+
         """Constructor for the FeatureUsage class"""
 
         # Initialize members of the class
@@ -33,7 +35,6 @@ class FeatureUsage(object):
         self.feature_name = feature_name
         self.num_vm = num_vm
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -57,8 +58,8 @@ class FeatureUsage(object):
         num_vm = dictionary.get('numVm')
 
         # Return an object of this model
-        return cls(current_usage_gib,
-                   feature_name,
-                   num_vm)
-
-
+        return cls(
+            current_usage_gib,
+            feature_name,
+            num_vm
+)
\ No newline at end of file
