@@ -1,34 +1,36 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class FileExtensionFilter(object):
 
     """Implementation of the 'FileExtensionFilter' model.
 
-    TODO: type model description here.
+    TODO: type description here.
+
 
     Attributes:
+
         file_extensions_list (list of string): The list of file extensions to
             apply
         is_enabled (bool): If set, it enables the file extension filter
         mode (ModeFileExtensionFilterEnum): The mode applied to the list of
-            file extensions 'kWhitelist' indicates a whitelist extension
-            filter. 'kBlacklist' indicates a blacklist extension filter.
-
+            file extensions 'kWhitelist' indicates a allowlist extension
+            filter. 'kBlacklist' indicates a denylist extension filter.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "file_extensions_list":'fileExtensionsList',
         "is_enabled":'isEnabled',
-        "mode":'mode'
+        "mode":'mode',
     }
-
     def __init__(self,
                  file_extensions_list=None,
                  is_enabled=None,
-                 mode=None):
+                 mode=None,
+            ):
+
         """Constructor for the FileExtensionFilter class"""
 
         # Initialize members of the class
@@ -36,7 +38,6 @@ class FileExtensionFilter(object):
         self.is_enabled = is_enabled
         self.mode = mode
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -55,13 +56,13 @@ class FileExtensionFilter(object):
             return None
 
         # Extract variables from the dictionary
-        file_extensions_list = dictionary.get('fileExtensionsList')
+        file_extensions_list = dictionary.get("fileExtensionsList")
         is_enabled = dictionary.get('isEnabled')
         mode = dictionary.get('mode')
 
         # Return an object of this model
-        return cls(file_extensions_list,
-                   is_enabled,
-                   mode)
-
-
+        return cls(
+            file_extensions_list,
+            is_enabled,
+            mode
+)
\ No newline at end of file
