@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class FilterIpConfig(object):
 
@@ -9,32 +8,34 @@ class FilterIpConfig(object):
     Specifies the list of IP addresses that are allowed or denied at the job
     level. Allowed IPs and Denied IPs cannot be used together.
 
+
     Attributes:
+
         allowed_ip_addresses (list of string): Specifies the IP addresses that
             should be used exclusively at the job level. Cannot be set if
             deniedIpAddresses is set.
         denied_ip_addresses (list of string): Specifies the IP addresses that
             should not be used at the job level. Cannot be set if
             allowedIpAddresses is set.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "allowed_ip_addresses": 'allowedIpAddresses',
-        "denied_ip_addresses": 'deniedIpAddresses'
+        "allowed_ip_addresses":'allowedIpAddresses',
+        "denied_ip_addresses":'deniedIpAddresses',
     }
-
     def __init__(self,
                  allowed_ip_addresses=None,
-                 denied_ip_addresses=None):
+                 denied_ip_addresses=None,
+            ):
+
         """Constructor for the FilterIpConfig class"""
 
         # Initialize members of the class
         self.allowed_ip_addresses = allowed_ip_addresses
         self.denied_ip_addresses = denied_ip_addresses
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -53,11 +54,11 @@ class FilterIpConfig(object):
             return None
 
         # Extract variables from the dictionary
-        allowed_ip_addresses = dictionary.get('allowedIpAddresses', None)
-        denied_ip_addresses = dictionary.get('deniedIpAddresses', None)
+        allowed_ip_addresses = dictionary.get("allowedIpAddresses")
+        denied_ip_addresses = dictionary.get("deniedIpAddresses")
 
         # Return an object of this model
-        return cls(allowed_ip_addresses,
-                   denied_ip_addresses)
-
-
+        return cls(
+            allowed_ip_addresses,
+            denied_ip_addresses
+)
\ No newline at end of file
