@@ -1,38 +1,39 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class GranteeProto(object):
 
     """Implementation of the 'GranteeProto' model.
 
-    Message to define a grantee to which ACL permissions can be granted.
+    TODO: type description here.
+
 
     Attributes:
-        email_address (string): If grantee is of type 'kEmailUser', this
-            field will contain the email address of the user.
+
+        email_address (string): If grantee is of type 'kEmailUser', this field
+            will contain the email address of the user.
         group (int): If grantee is of type 'kGroup', this field will contain
             the group to which permission is granted.
         mtype (int): TODO: Type description here.
         user_id (string): If grantee is of type 'kRegisteredUser', this field
             will contain the canonical id of the user.
-
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "email_address":'emailAddress',
         "group":'group',
         "mtype":'type',
-        "user_id":'userId'
+        "user_id":'userId',
     }
-
     def __init__(self,
                  email_address=None,
                  group=None,
                  mtype=None,
-                 user_id=None):
+                 user_id=None,
+            ):
+
         """Constructor for the GranteeProto class"""
 
         # Initialize members of the class
@@ -41,7 +42,6 @@ class GranteeProto(object):
         self.mtype = mtype
         self.user_id = user_id
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -66,9 +66,9 @@ class GranteeProto(object):
         user_id = dictionary.get('userId')
 
         # Return an object of this model
-        return cls(email_address,
-                   group,
-                   mtype,
-                   user_id)
-
-
+        return cls(
+            email_address,
+            group,
+            mtype,
+            user_id
+)
\ No newline at end of file
