@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class GroupInfo(object):
 
@@ -8,28 +7,31 @@ class GroupInfo(object):
 
     Specifies struct with basic group details.
 
+
     Attributes:
+
         domain (string): Specifies domain name of the user.
         group_name (string): Specifies group name of the group.
         sid (string): Specifies unique Security ID (SID) of the user.
         tenant_ids (list of string): Specifies the tenants to which the group
             belongs to.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "domain":'domain',
         "group_name":'groupName',
         "sid":'sid',
-        "tenant_ids":'tenantIds'
+        "tenant_ids":'tenantIds',
     }
-
     def __init__(self,
                  domain=None,
                  group_name=None,
                  sid=None,
-                 tenant_ids=None):
+                 tenant_ids=None,
+            ):
+
         """Constructor for the GroupInfo class"""
 
         # Initialize members of the class
@@ -38,7 +40,6 @@ class GroupInfo(object):
         self.sid = sid
         self.tenant_ids = tenant_ids
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -60,12 +61,12 @@ class GroupInfo(object):
         domain = dictionary.get('domain')
         group_name = dictionary.get('groupName')
         sid = dictionary.get('sid')
-        tenant_ids = dictionary.get('tenantIds')
+        tenant_ids = dictionary.get("tenantIds")
 
         # Return an object of this model
-        return cls(domain,
-                   group_name,
-                   sid,
-                   tenant_ids)
-
-
+        return cls(
+            domain,
+            group_name,
+            sid,
+            tenant_ids
+)
\ No newline at end of file
