@@ -1,37 +1,38 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class HBaseConnectParams(object):
 
     """Implementation of the 'HBaseConnectParams' model.
 
-    Specifies an Object containing information about a registered HBase
-    source.
+    Specifies an Object containing information about a registered HBase source.
+
 
     Attributes:
-        hdfs_entity_id long|int): The entity id of the HDFS source for this
+
+        hdfs_entity_id (long|int): The entity id of the HDFS source for this
             HBase
-        kerberos_principal (string): Specifies the kerberos principal
+        kerberos_principal (string): Specifies the kerberos principal.
         root_data_directory (string): Specifies the HBase data root directory.
         zookeeper_quorum (list of string): Specifies the HBase zookeeper
             quorum.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "hdfs_entity_id":'hdfsEntityId',
         "kerberos_principal":'kerberosPrincipal',
         "root_data_directory":'rootDataDirectory',
-        "zookeeper_quorum":'zookeeperQuorum'
+        "zookeeper_quorum":'zookeeperQuorum',
     }
-
     def __init__(self,
                  hdfs_entity_id=None,
                  kerberos_principal=None,
                  root_data_directory=None,
-                 zookeeper_quorum=None):
+                 zookeeper_quorum=None,
+            ):
+
         """Constructor for the HBaseConnectParams class"""
 
         # Initialize members of the class
@@ -40,7 +41,6 @@ class HBaseConnectParams(object):
         self.root_data_directory = root_data_directory
         self.zookeeper_quorum = zookeeper_quorum
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -62,12 +62,12 @@ class HBaseConnectParams(object):
         hdfs_entity_id = dictionary.get('hdfsEntityId')
         kerberos_principal = dictionary.get('kerberosPrincipal')
         root_data_directory = dictionary.get('rootDataDirectory')
-        zookeeper_quorum = dictionary.get('zookeeperQuorum')
+        zookeeper_quorum = dictionary.get("zookeeperQuorum")
 
         # Return an object of this model
-        return cls(hdfs_entity_id,
-                   kerberos_principal,
-                   root_data_directory,
-                   zookeeper_quorum)
-
-
+        return cls(
+            hdfs_entity_id,
+            kerberos_principal,
+            root_data_directory,
+            zookeeper_quorum
+)
\ No newline at end of file
