@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class HBaseTable(object):
 
@@ -8,24 +7,27 @@ class HBaseTable(object):
 
     Specifies an Object containing information about a HBase table.
 
-    Attributes:
-    approx_size_bytes (int): Specifies the approx size of the table in bytes.
 
+    Attributes:
+
+        approx_size_bytes (long|int): Specifies the approx size of the table in
+            bytes.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "approx_size_bytes":'approxSizeBytes'
+        "approx_size_bytes":'approxSizeBytes',
     }
-
     def __init__(self,
-                 approx_size_bytes=None):
+                 approx_size_bytes=None,
+            ):
+
         """Constructor for the HBaseTable class"""
 
         # Initialize members of the class
         self.approx_size_bytes = approx_size_bytes
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -47,6 +49,6 @@ class HBaseTable(object):
         approx_size_bytes = dictionary.get('approxSizeBytes')
 
         # Return an object of this model
-        return cls(approx_size_bytes)
-
-
+        return cls(
+            approx_size_bytes
+)
\ No newline at end of file
