@@ -1,39 +1,40 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
-
-class HypervBackupEnvParams(object):
+class HyperVBackupEnvParams(object):
 
     """Implementation of the 'HyperVBackupEnvParams' model.
 
     Message to capture any additional backup params for a HyperV environment.
 
+
     Attributes:
+
         allow_crash_consistent_snapshot (bool): Whether to fallback to take a
             crash-consistent snapshot incase taking an app-consistent snapshot
             fails.
         backup_job_type (int): The type of backup job to use. Default is to
             auto-detect the best type to use based on the VMs to backup. End
             user may select RCT or VSS also.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "allow_crash_consistent_snapshot":'allowCrashConsistentSnapshot',
-        "backup_job_type":'backupJobType'
+        "backup_job_type":'backupJobType',
     }
-
     def __init__(self,
                  allow_crash_consistent_snapshot=None,
-                 backup_job_type=None):
-        """Constructor for the HypervBackupEnvParams class"""
+                 backup_job_type=None,
+            ):
+
+        """Constructor for the HyperVBackupEnvParams class"""
 
         # Initialize members of the class
         self.allow_crash_consistent_snapshot = allow_crash_consistent_snapshot
         self.backup_job_type = backup_job_type
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -56,7 +57,7 @@ class HypervBackupEnvParams(object):
         backup_job_type = dictionary.get('backupJobType')
 
         # Return an object of this model
-        return cls(allow_crash_consistent_snapshot,
-                   backup_job_type)
-
-
+        return cls(
+            allow_crash_consistent_snapshot,
+            backup_job_type
+)
\ No newline at end of file
