@@ -1,42 +1,43 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class HypervRestoreParameters(object):
 
     """Implementation of the 'HypervRestoreParameters' model.
 
-    Specifies information needed when restoring VMs in HyperV enviroment.
-    This field defines the HyperV specific params for restore tasks of type
+    Specifies information needed when restoring VMs in HyperV enviroment. This
+    field defines the HyperV specific params for restore tasks of type
     kRecoverVMs.
 
+
     Attributes:
+
         datastore_id (long|int): A datastore entity where the object's files
             should be restored to. This field is optional if object is being
             restored to its original parent source. If not specified, the
             object's files will be restored to their original datastore
-            locations. This field is mandatory if object is being restored to
-            a different resource entity or to a different parent source.
-        disable_network (bool): Specifies whether the network should be left
-            in disabled state. Attached network is enabled by default. Set
-            this flag to true to disable it.
-        network_id (long|int): Specifies a network configuration to be
-            attached to the cloned or recovered object. For kCloneVMs and
-            kRecoverVMs tasks, original network configuration is detached if
-            the cloned or recovered object is kept under a different parent
-            Protection Source or a different Resource Pool. By default, for
-            kRecoverVMs task, original network configuration is preserved if
-            the recovered object is kept under the same parent Protection
-            Source and the same Resource Pool. Specify this field to override
-            the preserved network configuration or to attach a new network
-            configuration to the cloned or recovered objects. You can get the
-            networkId of the kNetwork object by setting includeNetworks to
-            'true' in the GET /public/protectionSources operation. In the
-            response, get the id of the desired kNetwork object, the resource
-            pool, and the registered parent Protection Source.
-        powered_on (bool): Specifies the power state of the cloned or
-            recovered objects. By default, the cloned or recovered objects are
-            powered off.
+            locations. This field is mandatory if object is being restored to a
+            different resource entity or to a different parent source.
+        disable_network (bool): Specifies whether the network should be left in
+            disabled state. Attached network is enabled by default. Set this
+            flag to true to disable it.
+        network_id (long|int): Specifies a network configuration to be attached
+            to the cloned or recovered object. For kCloneVMs and kRecoverVMs
+            tasks, original network configuration is detached if the cloned or
+            recovered object is kept under a different parent Protection Source
+            or a different Resource Pool. By default, for kRecoverVMs task,
+            original network configuration is preserved if the recovered object
+            is kept under the same parent Protection Source and the same
+            Resource Pool. Specify this field to override the preserved network
+            configuration or to attach a new network configuration to the
+            cloned or recovered objects. You can get the networkId of the
+            kNetwork object by setting includeNetworks to 'true' in the GET
+            /public/protectionSources operation. In the response, get the id of
+            the desired kNetwork object, the resource pool, and the registered
+            parent Protection Source.
+        powered_on (bool): Specifies the power state of the cloned or recovered
+            objects. By default, the cloned or recovered objects are powered
+            off.
         prefix (string): Specifies a prefix to prepended to the source object
             name to derive a new name for the recovered or cloned object. By
             default, cloned or recovered objects retain their original name.
@@ -53,9 +54,9 @@ class HypervRestoreParameters(object):
             object name to derive a new name for the recovered or cloned
             object. By default, cloned or recovered objects retain their
             original name. Length of this field is limited to 8 characters.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "datastore_id":'datastoreId',
@@ -65,9 +66,8 @@ class HypervRestoreParameters(object):
         "prefix":'prefix',
         "preserve_tags":'preserveTags',
         "resource_id":'resourceId',
-        "suffix":'suffix'
+        "suffix":'suffix',
     }
-
     def __init__(self,
                  datastore_id=None,
                  disable_network=None,
@@ -76,7 +76,9 @@ class HypervRestoreParameters(object):
                  prefix=None,
                  preserve_tags=None,
                  resource_id=None,
-                 suffix=None):
+                 suffix=None,
+            ):
+
         """Constructor for the HypervRestoreParameters class"""
 
         # Initialize members of the class
@@ -89,7 +91,6 @@ class HypervRestoreParameters(object):
         self.resource_id = resource_id
         self.suffix = suffix
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -113,18 +114,18 @@ class HypervRestoreParameters(object):
         network_id = dictionary.get('networkId')
         powered_on = dictionary.get('poweredOn')
         prefix = dictionary.get('prefix')
-        preserve_tags = dictionary.get('preserveTags', None)
+        preserve_tags = dictionary.get('preserveTags')
         resource_id = dictionary.get('resourceId')
         suffix = dictionary.get('suffix')
 
         # Return an object of this model
-        return cls(datastore_id,
-                   disable_network,
-                   network_id,
-                   powered_on,
-                   prefix,
-                   preserve_tags,
-                   resource_id,
-                   suffix)
-
-
+        return cls(
+            datastore_id,
+            disable_network,
+            network_id,
+            powered_on,
+            prefix,
+            preserve_tags,
+            resource_id,
+            suffix
+)
\ No newline at end of file
