@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class IdpServiceConfiguration(object):
 
@@ -8,7 +7,9 @@ class IdpServiceConfiguration(object):
 
     Specifies the configuration of an IdP service.
 
+
     Attributes:
+
         allow_local_authentication (bool): Specifies whether to allow local
             authentication. When IdP is configured, only IdP users are allowed
             to login to the Cluster. Local login is disabled except for users
@@ -30,32 +31,31 @@ class IdpServiceConfiguration(object):
             service.
         issuer_id (string): Specifies the IdP provided Issuer ID for the app.
             For example, exkh1aov1nhHrgFhN0h7.
-        name (string): Specifies the name of the vendor providing IdP
-            service.
-        roles (list of string):  Specifies a list of roles assigned to an IdP
+        name (string): Specifies the name of the vendor providing IdP service.
+        roles (list of string): Specifies a list of roles assigned to an IdP
             user if samlAttributeName is not given.
         saml_attribute_name (string): Specifies the SAML attribute name that
-            contains a comma separated list of Cluster roles. Either this
-            field or roles must be set. This field takes higher precedence
-            than the roles field.
-        sign_request (bool): Specifies whether to sign the SAML request or
-            not. When it is set to true, SAML request will be signed. When it
-            is set to false, SAML request is not signed. Default is false. Set
-            this flag to true if the IdP site is configured to expect the SAML
-            request from the Cluster signed. If this is set to true, users
-            must get the Cluster's certificate and upload it on the IdP site.
+            contains a comma separated list of Cluster roles. Either this field
+            or roles must be set. This field takes higher precedence than the
+            roles field.
+        sign_request (bool): Specifies whether to sign the SAML request or not.
+            When it is set to true, SAML request will be signed. When it is set
+            to false, SAML request is not signed. Default is false. Set this
+            flag to true if the IdP site is configured to expect the SAML
+            request from the Cluster signed. If this is set to true, users must
+            get the Cluster's certificate and upload it on the IdP site.
         sso_url (string): Specifies the SSO URL of the IdP service for the
-            customer. This is the URL given by IdP when the customer created
-            an account. Customers may use this for several clusters that are
+            customer. This is the URL given by IdP when the customer created an
+            account. Customers may use this for several clusters that are
             registered with on IdP site. For example,
             dev-332534.oktapreview.com
         tenant_id (string): Specifies the Tenant Id if the IdP is configured
             for a Tenant. If this is not set, this IdP configuration is used
-            for the Cluster level users and for all users of Tenants not
-            having an IdP configuration.
-
+            for the Cluster level users and for all users of Tenants not having
+            an IdP configuration.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "allow_local_authentication":'allowLocalAuthentication',
@@ -70,9 +70,8 @@ class IdpServiceConfiguration(object):
         "saml_attribute_name":'samlAttributeName',
         "sign_request":'signRequest',
         "sso_url":'ssoUrl',
-        "tenant_id":'tenantId'
+        "tenant_id":'tenantId',
     }
-
     def __init__(self,
                  allow_local_authentication=None,
                  certificate=None,
@@ -86,7 +85,9 @@ class IdpServiceConfiguration(object):
                  saml_attribute_name=None,
                  sign_request=None,
                  sso_url=None,
-                 tenant_id=None):
+                 tenant_id=None,
+            ):
+
         """Constructor for the IdpServiceConfiguration class"""
 
         # Initialize members of the class
@@ -104,7 +105,6 @@ class IdpServiceConfiguration(object):
         self.sso_url = sso_url
         self.tenant_id = tenant_id
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -131,25 +131,25 @@ class IdpServiceConfiguration(object):
         id = dictionary.get('id')
         issuer_id = dictionary.get('issuerId')
         name = dictionary.get('name')
-        roles = dictionary.get('roles')
+        roles = dictionary.get("roles")
         saml_attribute_name = dictionary.get('samlAttributeName')
         sign_request = dictionary.get('signRequest')
         sso_url = dictionary.get('ssoUrl')
         tenant_id = dictionary.get('tenantId')
 
         # Return an object of this model
-        return cls(allow_local_authentication,
-                   certificate,
-                   certificate_filename,
-                   domain,
-                   enable,
-                   id,
-                   issuer_id,
-                   name,
-                   roles,
-                   saml_attribute_name,
-                   sign_request,
-                   sso_url,
-                   tenant_id)
-
-
+        return cls(
+            allow_local_authentication,
+            certificate,
+            certificate_filename,
+            domain,
+            enable,
+            id,
+            issuer_id,
+            name,
+            roles,
+            saml_attribute_name,
+            sign_request,
+            sso_url,
+            tenant_id
+)
\ No newline at end of file
