@@ -1,34 +1,35 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class IsilonEnvParams_ZoneConfig_NetworkPoolConfig(object):
 
     """Implementation of the 'IsilonEnvParams_ZoneConfig_NetworkPoolConfig' model.
 
-    Network Pool Configuration.
+    TODO: type description here.
+
 
     Attributes:
+
         pool_name (string): The name of the pool.
         subnet (string): Name of the subnet the pool belongs to.
         use_smartconnect (bool): Whether to use SmartConnect if available. If
             true, DNS name for the SmartConnect zone will be used to balance
             the IPs. Otherwise, pool IPs will be balanced manually.
-
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "pool_name":'poolName',
         "subnet":'subnet',
-        "use_smartconnect":'useSmartconnect'
+        "use_smartconnect":'useSmartconnect',
     }
-
     def __init__(self,
                  pool_name=None,
                  subnet=None,
-                 use_smartconnect=None):
+                 use_smartconnect=None,
+            ):
+
         """Constructor for the IsilonEnvParams_ZoneConfig_NetworkPoolConfig class"""
 
         # Initialize members of the class
@@ -36,7 +37,6 @@ class IsilonEnvParams_ZoneConfig_NetworkPoolConfig(object):
         self.subnet = subnet
         self.use_smartconnect = use_smartconnect
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -60,8 +60,8 @@ class IsilonEnvParams_ZoneConfig_NetworkPoolConfig(object):
         use_smartconnect = dictionary.get('useSmartconnect')
 
         # Return an object of this model
-        return cls(pool_name,
-                   subnet,
-                   use_smartconnect)
-
-
+        return cls(
+            pool_name,
+            subnet,
+            use_smartconnect
+)
\ No newline at end of file
