@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class KubernetesLabelAttribute(object):
 
@@ -8,25 +7,28 @@ class KubernetesLabelAttribute(object):
 
     Specifies a Kubernetes label.
 
+
     Attributes:
+
         id (long|int): Specifies the Cohesity id of the K8s label.
         name (string): Specifies the appended key and value of the K8s label.
-        uuid (string): Specifies Kubernetes Unique Identifier (UUID) of the
-            K8s label.
-
+        uuid (string): Specifies Kubernetes Unique Identifier (UUID) of the K8s
+            label.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "id":'id',
         "name":'name',
-        "uuid":'uuid'
+        "uuid":'uuid',
     }
-
     def __init__(self,
                  id=None,
                  name=None,
-                 uuid=None):
+                 uuid=None,
+            ):
+
         """Constructor for the KubernetesLabelAttribute class"""
 
         # Initialize members of the class
@@ -34,7 +36,6 @@ class KubernetesLabelAttribute(object):
         self.name = name
         self.uuid = uuid
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -58,8 +59,8 @@ class KubernetesLabelAttribute(object):
         uuid = dictionary.get('uuid')
 
         # Return an object of this model
-        return cls(id,
-                   name,
-                   uuid)
-
-
+        return cls(
+            id,
+            name,
+            uuid
+)
\ No newline at end of file
