@@ -1,19 +1,16 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class LastRunStatusEnum(object):
 
     """Implementation of the 'LastRunStatus' enum.
+    Specifies the Job Run status of the last Job Run protecting this Protection
+    Source Object. 'kSuccess' indicates that the Job Run was successful.
+    'kRunning' indicates that the Job Run is currently running. 'kWarning'
+    indicates that the Job Run was successful but warnings were issued.
+    'kCancelled' indicates that the Job Run was canceled. 'kError' indicates
+    the Job Run encountered an error and did not run to completion.
 
-    Specifies the Job Run status of the last Job Run protecting
-    this Protection Source Object.
-    'kSuccess' indicates that the Job Run was successful.
-    'kRunning' indicates that the Job Run is currently running.
-    'kWarning' indicates that the Job Run was successful but warnings were
-    issued.
-    'kCancelled' indicates that the Job Run was canceled.
-    'kError' indicates the Job Run encountered an error and did not run to
-    completion.
 
     Attributes:
         KSUCCESS: TODO: type description here.
@@ -33,4 +30,3 @@ class LastRunStatusEnum(object):
     KCANCELLED = 'kCancelled'
 
     KERROR = 'kError'
-
