@@ -1,32 +1,36 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class LifecycleRuleFilterTag(object):
 
     """Implementation of the 'LifecycleRuleFilterTag' model.
 
-    Attributes:
-        key (string): TODO: type description here
-        value (string): TODO: type description here
+    TODO: type description here.
 
+
+    Attributes:
+
+        key (string): Name of the object key.
+        value (string): Value of the tag.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "key":'key',
-        "value":'value'
+        "value":'value',
     }
-
     def __init__(self,
                  key=None,
-                 value=None):
+                 value=None,
+            ):
+
         """Constructor for the LifecycleRuleFilterTag class"""
 
         # Initialize members of the class
         self.key = key
         self.value = value
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -45,10 +49,11 @@ class LifecycleRuleFilterTag(object):
             return None
 
         # Extract variables from the dictionary
-        key = dictionary.get('key', None)
-        value = dictionary.get('value', None)
+        key = dictionary.get('key')
+        value = dictionary.get('value')
 
         # Return an object of this model
-        return cls(key, value)
-
-
+        return cls(
+            key,
+            value
+)
\ No newline at end of file
