@@ -1,31 +1,33 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class LinuxSupportUserBashShellAccessReqParams(object):
 
     """Implementation of the 'LinuxSupportUserBashShellAccessReqParams' model.
 
-    Linux Support Bash Shell Access Req Params.
+    TODO: type description here.
+
 
     Attributes:
+
         regenerate_token (bool): If RegenerateToken is set to true, the token
             would be regenerated and the new token will be returned.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "regenerate_token":'regenerateToken'
+        "regenerate_token":'regenerateToken',
     }
-
     def __init__(self,
-                 regenerate_token=None):
+                 regenerate_token=None,
+            ):
+
         """Constructor for the LinuxSupportUserBashShellAccessReqParams class"""
 
         # Initialize members of the class
         self.regenerate_token = regenerate_token
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -47,6 +49,6 @@ class LinuxSupportUserBashShellAccessReqParams(object):
         regenerate_token = dictionary.get('regenerateToken')
 
         # Return an object of this model
-        return cls(regenerate_token)
-
-
+        return cls(
+            regenerate_token
+)
\ No newline at end of file
