@@ -1,18 +1,17 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class LogicalVolumeTypeEnum(object):
 
     """Implementation of the 'LogicalVolumeType' enum.
-
     Specifies the type of logical volume such as kSimpleVolume, kLVM or kLDM.
     'kSimpleVolume' indicates a simple volume. Data can be used by just
-    mounting the only one partition present on the disk.
-    'kLVM' indicates a logical volume on Linux managed by a Logical Volume
-    Manager. In order to access the data, deviceTree must be created based
-    on the specification in logicalVolume.deviceTree.
-    'kLDM' indicates a logical volume on Windows managed by Logical Disk
-    Manager.
+    mounting the only one partition present on the disk. 'kLVM' indicates a
+    logical volume on Linux managed by a Logical Volume Manager. In order to
+    access the data, deviceTree must be created based on the specification in
+    logicalVolume.deviceTree. 'kLDM' indicates a logical volume on Windows
+    managed by Logical Disk Manager.
+
 
     Attributes:
         KSIMPLEVOLUME: TODO: type description here.
@@ -26,4 +25,3 @@ class LogicalVolumeTypeEnum(object):
     KLVM = 'kLVM'
 
     KLDM = 'kLDM'
-
