@@ -1,36 +1,43 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.value_data
 
+
 class MetricDataPoint(object):
 
     """Implementation of the 'MetricDataPoint' model.
 
     Specifies information about a single data point in a time series.
 
+
     Attributes:
-        data (ValueData): Specifies the fields to store data of a given type.
-            Specify data in the appropriate field for the current data type.
+
+        data (Value_Data): Corresponding value of a metric at the given
+            timestamp. When client adds or pushes the stats, this field must be
+            specified. When Stats module, returns the time series data, this
+            field could be empty if data point is not available for the given
+            timestamp.
         rollup_function (int): If this is a rolled up data point, following
             enum denotes the rollup function used for rolling up. For a raw
             point this enum is not set.
         timestamp_msecs (long|int): Specifies a timestamp when the metric data
             point was captured.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "data":'data',
         "rollup_function":'rollupFunction',
-        "timestamp_msecs":'timestampMsecs'
+        "timestamp_msecs":'timestampMsecs',
     }
-
     def __init__(self,
                  data=None,
                  rollup_function=None,
-                 timestamp_msecs=None):
+                 timestamp_msecs=None,
+            ):
+
         """Constructor for the MetricDataPoint class"""
 
         # Initialize members of the class
@@ -38,7 +45,6 @@ class MetricDataPoint(object):
         self.rollup_function = rollup_function
         self.timestamp_msecs = timestamp_msecs
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -57,13 +63,13 @@ class MetricDataPoint(object):
             return None
 
         # Extract variables from the dictionary
-        data = cohesity_management_sdk.models.value_data.ValueData.from_dictionary(dictionary.get('data')) if dictionary.get('data') else None
+        data = cohesity_management_sdk.models.value_data.Value_Data.from_dictionary(dictionary.get('data')) if dictionary.get('data') else None
         rollup_function = dictionary.get('rollupFunction')
         timestamp_msecs = dictionary.get('timestampMsecs')
 
         # Return an object of this model
-        return cls(data,
-                   rollup_function,
-                   timestamp_msecs)
-
-
+        return cls(
+            data,
+            rollup_function,
+            timestamp_msecs
+)
\ No newline at end of file
