@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class MSExchangeParams(object):
 
@@ -8,25 +7,27 @@ class MSExchangeParams(object):
 
     All the params specific to MS exchange application.
 
+
     Attributes:
+
         perform_log_truncation (bool): If this is set to true, then an attempt
             will be made to truncate exchange logs.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "perform_log_truncation":'performLogTruncation'
+        "perform_log_truncation":'performLogTruncation',
     }
-
     def __init__(self,
-                 perform_log_truncation=None):
+                 perform_log_truncation=None,
+            ):
+
         """Constructor for the MSExchangeParams class"""
 
         # Initialize members of the class
         self.perform_log_truncation = perform_log_truncation
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -48,6 +49,6 @@ class MSExchangeParams(object):
         perform_log_truncation = dictionary.get('performLogTruncation')
 
         # Return an object of this model
-        return cls(perform_log_truncation)
-
-
+        return cls(
+            perform_log_truncation
+)
\ No newline at end of file
