@@ -1,34 +1,36 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class NasAnalysisJobParams_AccessTimeBucket(object):
 
     """Implementation of the 'NasAnalysisJobParams_AccessTimeBucket' model.
 
-    Access time bucket.
+    TODO: type description here.
+
 
     Attributes:
+
         access_time_bucket_name (string): Tag representing the bucket for
-            access time of file.
-            e.g. "1mo-3mo" represents 1 month to 3 month.
-        access_time_end_days (long|int): End time e.g. 1 year. Stored in
-            days precision.
+            access time of file. e.g. "1mo-3mo" represents 1 month to 3 month.
+        access_time_end_days (long|int): End time e.g. 1 year. Stored in days
+            precision.
         access_time_start_days (long|int): Start time e.g. 6 months. Stored in
             days precision.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "access_time_bucket_name":'accessTimeBucketName',
         "access_time_end_days":'accessTimeEndDays',
-        "access_time_start_days":'accessTimeStartDays'
+        "access_time_start_days":'accessTimeStartDays',
     }
-
     def __init__(self,
                  access_time_bucket_name=None,
                  access_time_end_days=None,
-                 access_time_start_days=None):
+                 access_time_start_days=None,
+            ):
+
         """Constructor for the NasAnalysisJobParams_AccessTimeBucket class"""
 
         # Initialize members of the class
@@ -36,7 +38,6 @@ class NasAnalysisJobParams_AccessTimeBucket(object):
         self.access_time_end_days = access_time_end_days
         self.access_time_start_days = access_time_start_days
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -60,8 +61,8 @@ class NasAnalysisJobParams_AccessTimeBucket(object):
         access_time_start_days = dictionary.get('accessTimeStartDays')
 
         # Return an object of this model
-        return cls(access_time_bucket_name,
-                   access_time_end_days,
-                   access_time_start_days)
-
-
+        return cls(
+            access_time_bucket_name,
+            access_time_end_days,
+            access_time_start_days
+)
\ No newline at end of file
