@@ -1,32 +1,34 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class NasAnalysisJobParams_FileSizeBucket(object):
 
     """Implementation of the 'NasAnalysisJobParams_FileSizeBucket' model.
 
-    File size bucket.
+    TODO: type description here.
+
 
     Attributes:
-        file_size_bucket_name (string):  Tag representing the bucket for size
-            of file.
-            e.g. "1M-10M" represents 1 MB to 10 MB.
+
+        file_size_bucket_name (string): Tag representing the bucket for size of
+            file. e.g. "1M-10M" represents 1 MB to 10 MB.
         file_size_end_bytes (long|int): End size for the bucket e.g. 500MB.
         file_size_start_bytes (long|int): Start size for the bucket e.g. 50MB.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "file_size_bucket_name":'fileSizeBucketName',
         "file_size_end_bytes":'fileSizeEndBytes',
-        "file_size_start_bytes":'fileSizeStartBytes'
+        "file_size_start_bytes":'fileSizeStartBytes',
     }
-
     def __init__(self,
                  file_size_bucket_name=None,
                  file_size_end_bytes=None,
-                 file_size_start_bytes=None):
+                 file_size_start_bytes=None,
+            ):
+
         """Constructor for the NasAnalysisJobParams_FileSizeBucket class"""
 
         # Initialize members of the class
@@ -34,7 +36,6 @@ class NasAnalysisJobParams_FileSizeBucket(object):
         self.file_size_end_bytes = file_size_end_bytes
         self.file_size_start_bytes = file_size_start_bytes
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -58,8 +59,8 @@ class NasAnalysisJobParams_FileSizeBucket(object):
         file_size_start_bytes = dictionary.get('fileSizeStartBytes')
 
         # Return an object of this model
-        return cls(file_size_bucket_name,
-                   file_size_end_bytes,
-                   file_size_start_bytes)
-
-
+        return cls(
+            file_size_bucket_name,
+            file_size_end_bytes,
+            file_size_start_bytes
+)
\ No newline at end of file
