@@ -1,33 +1,37 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.task_notification
 
+
 class Notifications(object):
 
     """Implementation of the 'Notifications' model.
 
     All the Notification events generated for a given user. This is used for
-    transferring notifications over wire.
+    for transferring notifications over wire.
+
 
     Attributes:
+
         count (long|int): Notification Count.
         notification_list (list of TaskNotification): Notification list.
         unread_count (long|int): Unread Notification Count.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "count":'count',
         "notification_list":'notificationList',
-        "unread_count":'unreadCount'
+        "unread_count":'unreadCount',
     }
-
     def __init__(self,
                  count=None,
                  notification_list=None,
-                 unread_count=None):
+                 unread_count=None,
+            ):
+
         """Constructor for the Notifications class"""
 
         # Initialize members of the class
@@ -35,7 +39,6 @@ class Notifications(object):
         self.notification_list = notification_list
         self.unread_count = unread_count
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -63,8 +66,8 @@ class Notifications(object):
         unread_count = dictionary.get('unreadCount')
 
         # Return an object of this model
-        return cls(count,
-                   notification_list,
-                   unread_count)
-
-
+        return cls(
+            count,
+            notification_list,
+            unread_count
+)
\ No newline at end of file
