@@ -1,37 +1,38 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class NtpSettingsConfig(object):
 
     """Implementation of the 'NtpSettingsConfig' model.
 
-    TODO: type model description here.
+    TODO: type description here.
+
 
     Attributes:
+
         ntp_authentication_enabled (bool): Flag to specify if the cluster is
             using NTP with authentication.
         ntp_servers_internal (bool): Flag to specify if the NTP servers are on
             internal network or not.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "ntp_authentication_enabled":'ntpAuthenticationEnabled',
-        "ntp_servers_internal":'ntpServersInternal'
+        "ntp_servers_internal":'ntpServersInternal',
     }
-
     def __init__(self,
                  ntp_authentication_enabled=None,
-                 ntp_servers_internal=None):
+                 ntp_servers_internal=None,
+            ):
+
         """Constructor for the NtpSettingsConfig class"""
 
         # Initialize members of the class
         self.ntp_authentication_enabled = ntp_authentication_enabled
         self.ntp_servers_internal = ntp_servers_internal
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -54,7 +55,7 @@ class NtpSettingsConfig(object):
         ntp_servers_internal = dictionary.get('ntpServersInternal')
 
         # Return an object of this model
-        return cls(ntp_authentication_enabled,
-                   ntp_servers_internal)
-
-
+        return cls(
+            ntp_authentication_enabled,
+            ntp_servers_internal
+)
\ No newline at end of file
