@@ -1,16 +1,15 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class ObjectClassEnum(object):
 
     """Implementation of the 'ObjectClass' enum.
-
     Specifies the object class of the principal (either 'kGroup' or 'kUser').
-    'kUser' specifies a user object class.
-    'kGroup' specifies a group object class.
-    'kComputer' specifies a computer object class.
-    'kWellKnownPrincipal' specifies a well known principal.
-    'kServiceAccount' specifies a service account object class.
+    'kUser' specifies a user object class. 'kGroup' specifies a group object
+    class. 'kComputer' specifies a computer object class. 'kWellKnownPrincipal'
+    specifies a well known principal. 'kServiceAccount' specifies a service
+    account object class.
+
 
     Attributes:
         KUSER: TODO: type description here.
@@ -30,4 +29,3 @@ class ObjectClassEnum(object):
     KWELLKNOWNPRINCIPAL = 'kWellKnownPrincipal'
 
     KSERVICEACCOUNT = 'kServiceAccount'
-
