@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class OrgVdcNetwork(object):
 
@@ -8,25 +7,28 @@ class OrgVdcNetwork(object):
 
     Specifies the parameters of an Org VDC network.
 
+
     Attributes:
+
         name (string): Specifies the name of the Org VDC Network.
         vcd_uuid (string): Specifies the UUID as identified by the VCD.
         vcenter_uuid (string): Specifies the UUID of the corresponding network
             on the vCenter.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "name":'name',
         "vcd_uuid":'vcdUuid',
-        "vcenter_uuid":'vcenterUuid'
+        "vcenter_uuid":'vcenterUuid',
     }
-
     def __init__(self,
                  name=None,
                  vcd_uuid=None,
-                 vcenter_uuid=None):
+                 vcenter_uuid=None,
+            ):
+
         """Constructor for the OrgVdcNetwork class"""
 
         # Initialize members of the class
@@ -34,7 +36,6 @@ class OrgVdcNetwork(object):
         self.vcd_uuid = vcd_uuid
         self.vcenter_uuid = vcenter_uuid
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -58,8 +59,8 @@ class OrgVdcNetwork(object):
         vcenter_uuid = dictionary.get('vcenterUuid')
 
         # Return an object of this model
-        return cls(name,
-                   vcd_uuid,
-                   vcenter_uuid)
-
-
+        return cls(
+            name,
+            vcd_uuid,
+            vcenter_uuid
+)
\ No newline at end of file
