@@ -1,32 +1,36 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class PDBRestoreParam_RenamePdbMapEntry(object):
 
     """Implementation of the 'PDBRestoreParam_RenamePdbMapEntry' model.
 
-    Attributes:
-        key (string): TODO: type description here.
-        value (string): TODO: type description here.
+    TODO: type description here.
 
+
+    Attributes:
+
+        key (string): TODO: Type description here.
+        value (string): TODO: Type description here.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "key": 'key',
-        "value": 'value'
+        "key":'key',
+        "value":'value',
     }
-
     def __init__(self,
                  key=None,
-                 value=None):
+                 value=None,
+            ):
+
         """Constructor for the PDBRestoreParam_RenamePdbMapEntry class"""
 
         # Initialize members of the class
         self.key = key
         self.value = value
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -49,7 +53,7 @@ class PDBRestoreParam_RenamePdbMapEntry(object):
         value = dictionary.get('value')
 
         # Return an object of this model
-        return cls(key,
-                   value)
-
-
+        return cls(
+            key,
+            value
+)
\ No newline at end of file
