@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class PhysicalNodeConfiguration(object):
 
@@ -8,28 +7,31 @@ class PhysicalNodeConfiguration(object):
 
     Specifies the configuration for a node in the Cluster.
 
+
     Attributes:
+
         node_id (long|int): Specifies the Node ID for this node.
         node_ip (string): Specifies the Node IP address for this node.
         node_ipmi_ip (string): Specifies IPMI IP for this node.
         use_as_compute_node (bool): Specifies whether to use the Node for
             compute only.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "node_id":'nodeId',
         "node_ip":'nodeIp',
         "node_ipmi_ip":'nodeIpmiIp',
-        "use_as_compute_node":'useAsComputeNode'
+        "use_as_compute_node":'useAsComputeNode',
     }
-
     def __init__(self,
                  node_id=None,
                  node_ip=None,
                  node_ipmi_ip=None,
-                 use_as_compute_node=None):
+                 use_as_compute_node=None,
+            ):
+
         """Constructor for the PhysicalNodeConfiguration class"""
 
         # Initialize members of the class
@@ -38,7 +40,6 @@ class PhysicalNodeConfiguration(object):
         self.node_ipmi_ip = node_ipmi_ip
         self.use_as_compute_node = use_as_compute_node
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -63,9 +64,9 @@ class PhysicalNodeConfiguration(object):
         use_as_compute_node = dictionary.get('useAsComputeNode')
 
         # Return an object of this model
-        return cls(node_id,
-                   node_ip,
-                   node_ipmi_ip,
-                   use_as_compute_node)
-
-
+        return cls(
+            node_id,
+            node_ip,
+            node_ipmi_ip,
+            use_as_compute_node
+)
\ No newline at end of file
