@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class ProtectionJobInfo(object):
 
@@ -8,27 +7,29 @@ class ProtectionJobInfo(object):
 
     Specifies basic information about a Protection Job.
 
+
     Attributes:
+
         job_id (long|int): Specifies the id of the Protection Job.
         job_name (string): Specifies the name of the Protection Job.
-        mtype (TypeProtectionJobInfoEnum): Specifies the type of the
-            Protection Job such as kView or kPuppeteer. 'kPuppeteer' refers to
-            a Remote Adapter Job. Supported environment types such as 'kView',
-            'kSQL', 'kVMware', etc. NOTE: 'kPuppeteer' refers to Cohesity's
-            Remote Adapter. 'kVMware' indicates the VMware Protection Source
+        mtype (TypeProtectionJobInfoEnum): Specifies the type of the Protection
+            Job such as kView or kPuppeteer. 'kPuppeteer' refers to a Remote
+            Adapter Job. Supported environment types such as 'kView', 'kSQL',
+            'kVMware', etc. NOTE: 'kPuppeteer' refers to Cohesity's Remote
+            Adapter. 'kVMware' indicates the VMware Protection Source
             environment. 'kHyperV' indicates the HyperV Protection Source
             environment. 'kSQL' indicates the SQL Protection Source
             environment. 'kView' indicates the View Protection Source
             environment. 'kPuppeteer' indicates the Cohesity's Remote Adapter.
             'kPhysical' indicates the physical Protection Source environment.
             'kPure' indicates the Pure Storage Protection Source environment.
-            'Nimble' indicates the Nimble Storage Protection Source
+            'kNimble' indicates the Nimble Storage Protection Source
             environment. 'kAzure' indicates the Microsoft's Azure Protection
             Source environment. 'kNetapp' indicates the Netapp Protection
             Source environment. 'kAgent' indicates the Agent Protection Source
             environment. 'kGenericNas' indicates the Generic Network Attached
             Storage Protection Source environment. 'kAcropolis' indicates the
-            Acropolis Protection Source environment. 'kPhsicalFiles' indicates
+            Acropolis Protection Source environment. 'kPhysicalFiles' indicates
             the Physical Files Protection Source environment. 'kIsilon'
             indicates the Dell EMC's Isilon Protection Source environment.
             'kGPFS' indicates IBM's GPFS Protection Source environment. 'kKVM'
@@ -41,36 +42,45 @@ class ProtectionJobInfo(object):
             indicates the Flash Blade Protection Source environment.
             'kAWSNative' indicates the AWS Native Protection Source
             environment. 'kO365' indicates the Office 365 Protection Source
-            environment. 'kO365Outlook' indicates Office 365 outlook
-            Protection Source environment. 'kHyperFlex' indicates the Hyper
-            Flex Protection Source environment. 'kGCPNative' indicates the
-            GCP Native Protection Source environment. 'kAzureNative' indicates
-            the Azure Native Protection Source environment. 'kKubernetes'
-            indicates a Kubernetes Protection Source environment.
-            'kElastifile' indicates Elastifile Protection Source environment.
-            'kAD' indicates Active Directory Protection Source environment.
-            'kRDSSnapshotManager' indicates AWS RDS Protection Source
-            environment. 'kCassandra' indicates Cassandra Protection Source
-            environment. 'kMongoDB' indicates MongoDB Protection Source
-            environment. 'kCouchbase' indicates Couchbase Protection Source
-            environment. 'kHdfs' indicates Hdfs Protection Source environment.
-            'kHive' indicates Hive Protection Source environment. 'kHBase'
-            indicates HBase Protection Source environment.
-            'kUDA' indicates Universal Data Adapter Protection Source environment.
-
+            environment. 'kO365Outlook' indicates Office 365 outlook Protection
+            Source environment. 'kHyperFlex' indicates the Hyper Flex
+            Protection Source environment. 'kGCPNative' indicates the GCP
+            Native Protection Source environment. 'kAzureNative' indicates the
+            Azure Native Protection Source environment. 'kKubernetes' indicates
+            a Kubernetes Protection Source environment. 'kElastifile' indicates
+            Elastifile Protection Source environment. 'kAD' indicates Active
+            Directory Protection Source environment. 'kRDSSnapshotManager'
+            indicates AWS RDS Protection Source environment. 'kCassandra'
+            indicates Cassandra Protection Source environment. 'kMongoDB'
+            indicates MongoDB Protection Source environment. 'kCouchbase'
+            indicates Couchbase Protection Source environment. 'kHdfs'
+            indicates Hdfs Protection Source environment. 'kHive' indicates
+            Hive Protection Source environment. 'kHBase' indicates HBase
+            Protection Source environment. 'kUDA' indicates Universal Data
+            Adapter Protection Source environment. 'kO365Teams' indicates the
+            Office365 Teams Protection Source environment. 'kO365Group'
+            indicates the Office365 Groups Protection Source environment.
+            'kO365Exchange' indicates the Office365 Mailbox Protection Source
+            environment. 'kO365OneDrive' indicates the Office365 OneDrive
+            Protection Source environment. 'kO365Sharepoint' indicates the
+            Office365 SharePoint Protection Source environment.
+            'kO365PublicFolders' indicates the Office365 PublicFolders
+            Protection Source environment.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "job_id":'jobId',
         "job_name":'jobName',
-        "mtype":'type'
+        "mtype":'type',
     }
-
     def __init__(self,
                  job_id=None,
                  job_name=None,
-                 mtype=None):
+                 mtype=None,
+            ):
+
         """Constructor for the ProtectionJobInfo class"""
 
         # Initialize members of the class
@@ -78,7 +88,6 @@ class ProtectionJobInfo(object):
         self.job_name = job_name
         self.mtype = mtype
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -102,8 +111,8 @@ class ProtectionJobInfo(object):
         mtype = dictionary.get('type')
 
         # Return an object of this model
-        return cls(job_id,
-                   job_name,
-                   mtype)
-
-
+        return cls(
+            job_id,
+            job_name,
+            mtype
+)
\ No newline at end of file
