@@ -213,7 +213,7 @@ class ProtectionJobRequestBody(object):
             expected to complete, which is known as a Service-Level Agreement
             (SLA). A SLA violation is reported when the run time of a Job Run
             exceeds the SLA time period specified for this backup schedule.
-        name (string): Specifies the name of the Protection Job.
+        name (string, required): Specifies the name of the Protection Job.
         parent_source_id (long|int): Specifies the id of the registered
             Protection Source that is the parent of the Objects that may be
             protected by this Job. For example when a vCenter Server is
@@ -223,10 +223,10 @@ class ProtectionJobRequestBody(object):
             should be performed or not.
         perform_source_side_dedup (bool): Specifies whether source side dedupe
             should be performed or not.
-        policy_id (string): Specifies the unique id of the Protection Policy
-            associated with the Protection Job. The Policy provides retry
-            settings, Protection Schedules, Priority, SLA, etc. The Job defines
-            the Storage Domain (View Box), the Objects to Protect (if
+        policy_id (string, required): Specifies the unique id of the Protection
+            Policy associated with the Protection Job. The Policy provides
+            retry settings, Protection Schedules, Priority, SLA, etc. The Job
+            defines the Storage Domain (View Box), the Objects to Protect (if
             applicable), Start Time, Indexing settings, etc.
         post_backup_script (BackupScript): Specifies the script associated with
             the backup job. This field must be specified for 'kPhysical' jobs.
@@ -278,14 +278,14 @@ class ProtectionJobRequestBody(object):
             Datacenter could be selected but its child Host excluded. However,
             a child VM under the Host could be explicitly selected to be
             protected. Both the Datacenter and the VM are listed.
-        source_special_parameters (list of SourceSpecialParameter): Array of
-            Special Source Parameters.  Specifies additional settings that can
-            apply to a subset of the Sources listed in the Protection Job. For
-            example, you can specify a list of files and folders to protect
-            instead of protecting the entire Physical Server. If this field's
-            setting conflicts with environmentParameters, then this setting
-            will be used. Specific volume selections must be passed in here to
-            take effect.
+        source_special_parameters (list of SourceSpecialParameter, required):
+            Array of Special Source Parameters.  Specifies additional settings
+            that can apply to a subset of the Sources listed in the Protection
+            Job. For example, you can specify a list of files and folders to
+            protect instead of protecting the entire Physical Server. If this
+            field's setting conflicts with environmentParameters, then this
+            setting will be used. Specific volume selections must be passed in
+            here to take effect.
         start_time (TimeOfDay): Specifies the time of day to start the
             Protection Schedule. This is optional and only applicable if the
             Protection Policy defines a monthly or a daily Protection Schedule.
@@ -299,8 +299,8 @@ class ProtectionJobRequestBody(object):
             later searched in UI. For example, user can create a 'kPuppeteer'
             job to backup Oracle DB for 'payroll' department. User can specify
             following tags: 'payroll', 'Oracle_DB'.
-        view_box_id (long|int): Specifies the Storage Domain (View Box) id
-            where this Job writes data.
+        view_box_id (long|int, required): Specifies the Storage Domain (View
+            Box) id where this Job writes data.
         view_name (string): For a Remote Adapter 'kPuppeteer' Job or a 'kView'
             Job, this field specifies a View name that should be protected.
             Specify this field when creating a Protection Job for the first
