@@ -1,36 +1,31 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class ProtectionJobRunStats(object):
 
     """Implementation of the 'ProtectionJobRunStats' model.
 
-    Specifies statistics about a Protection Job Run.
-    This contains the Job Run level statistics.
+    Specifies statistics about a Protection Job Run. This contains the Job Run
+    level statistics.
+
 
     Attributes:
-        queue_duration_usecs (long|int): Specifies the duration between the
-            startTime and when gatekeeper permit is granted to the backup task.
-            If the backup task is rescheduled due to errors, the field is
-            updated considering the time when permit is granted again.
-            Queue duration = PermitGrantTimeUsecs - StartTimeUsecs
+
         total_bytes_tiered (long|int): Specifies the total amount of data
             successfully tiered from the source.
         admitted_time_usecs (long|int): Specifies the time the task was
-            unqueued from the queue to start running. This field can be used
-            to determine the following times: initial-wait-time =
+            unqueued from the queue to start running. This field can be used to
+            determine the following times: initial-wait-time =
             admittedTimeUsecs - startTimeUsecs run-time = endTimeUsecs -
-            admittedTimeUsecs If the task ends up waiting in other queues,
-            then actual run-time will be smaller than the run-time computed
-            this way. This field is only populated for Backup tasks
-            currently.
+            admittedTimeUsecs If the task ends up waiting in other queues, then
+            actual run-time will be smaller than the run-time computed this
+            way. This field is only populated for Backup tasks currently.
         end_time_usecs (long|int): Specifies the end time of the Protection
             Run. The end time is specified as a Unix epoch Timestamp (in
             microseconds).
         num_app_instances (int): Specifies the number of application instances
-            backed up by this Run. For example if the environment type is
-            kSQL, this field contains the number of SQL Server instances.
+            backed up by this Run. For example if the environment type is kSQL,
+            this field contains the number of SQL Server instances.
         num_canceled_tasks (long|int): Specifies the number of backup tasks
             that were canceled.
         num_cancelled_app_objects (int): Specifies the number of application
@@ -46,13 +41,18 @@ class ProtectionJobRunStats(object):
         num_successful_tasks (long|int): Specifies the number of backup tasks
             that completed successfully.
         permit_grant_time_usecs (long|int): Specifies the time when gatekeeper
-            permit is granted to the backup task.
+            permit is granted to the backup task. If the backup task is
+            rescheduled due to errors, the field is updated to the time when
+            permit is granted again.
+        queue_duration_usecs (long|int): "Specifies the duration between the
+            startTime and when gatekeeper permit is granted to the backup task.
             If the backup task is rescheduled due to errors, the field is
-            updated to the time when permit is granted again.
-        start_time_usecs (long|int): Specifies the start time of the
-            Protection Run. The start time is specified as a Unix epoch
-            Timestamp (in microseconds). This time is when the task is queued
-            to an internal queue where tasks are waiting to run.
+            updated considering the time when permit is granted again. Queue
+            duration = PermitGrantTimeUsecs - StartTimeUsecs"
+        start_time_usecs (long|int): Specifies the start time of the Protection
+            Run. The start time is specified as a Unix epoch Timestamp (in
+            microseconds). This time is when the task is queued to an internal
+            queue where tasks are waiting to run.
         time_taken_usecs (long|int): Specifies the actual execution time for
             the protection run to complete the backup task and the copy tasks.
             This time will not include the time waited in various internal
@@ -66,23 +66,22 @@ class ProtectionJobRunStats(object):
             storage after the snapshot is taken. The logical size of the data
             on the source if the data is fully hydrated or expanded and not
             reduced by change-block tracking, compression and deduplication.
-        total_physical_backup_size_bytes (long|int): Specifies the total
-            amount of physical space used on the Cohesity Cluster to store the
+        total_physical_backup_size_bytes (long|int): Specifies the total amount
+            of physical space used on the Cohesity Cluster to store the
             protected object after being reduced by change-block tracking,
             compression and deduplication. For example, if the logical backup
-            size is 1GB, but only 1MB was used on the Cohesity Cluster to
-            store it, this field be equal to 1MB.
+            size is 1GB, but only 1MB was used on the Cohesity Cluster to store
+            it, this field be equal to 1MB.
         total_source_size_bytes (long|int): Specifies the size of the source
-            object (such as a VM) protected by this task on the primary
-            storage before the snapshot is taken. The logical size of the data
-            on the source if the data is fully hydrated or expanded and not
-            reduced by change-block tracking, compression and deduplication.
-
+            object (such as a VM) protected by this task on the primary storage
+            before the snapshot is taken. The logical size of the data on the
+            source if the data is fully hydrated or expanded and not reduced by
+            change-block tracking, compression and deduplication.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "queue_duration_usecs":'QueueDurationUsecs',
         "total_bytes_tiered":'TotalBytesTiered',
         "admitted_time_usecs":'admittedTimeUsecs',
         "end_time_usecs":'endTimeUsecs',
@@ -94,17 +93,16 @@ class ProtectionJobRunStats(object):
         "num_successful_app_objects":'numSuccessfulAppObjects',
         "num_successful_tasks":'numSuccessfulTasks',
         "permit_grant_time_usecs":'permitGrantTimeUsecs',
+        "queue_duration_usecs":'queueDurationUsecs',
         "start_time_usecs":'startTimeUsecs',
         "time_taken_usecs":'timeTakenUsecs',
         "total_bytes_read_from_source":'totalBytesReadFromSource',
         "total_bytes_to_read_from_source":'totalBytesToReadFromSource',
         "total_logical_backup_size_bytes":'totalLogicalBackupSizeBytes',
         "total_physical_backup_size_bytes":'totalPhysicalBackupSizeBytes',
-        "total_source_size_bytes":'totalSourceSizeBytes'
+        "total_source_size_bytes":'totalSourceSizeBytes',
     }
-
     def __init__(self,
-                 queue_duration_usecs=None,
                  total_bytes_tiered=None,
                  admitted_time_usecs=None,
                  end_time_usecs=None,
@@ -116,17 +114,19 @@ class ProtectionJobRunStats(object):
                  num_successful_app_objects=None,
                  num_successful_tasks=None,
                  permit_grant_time_usecs=None,
+                 queue_duration_usecs=None,
                  start_time_usecs=None,
                  time_taken_usecs=None,
                  total_bytes_read_from_source=None,
                  total_bytes_to_read_from_source=None,
                  total_logical_backup_size_bytes=None,
                  total_physical_backup_size_bytes=None,
-                 total_source_size_bytes=None):
+                 total_source_size_bytes=None,
+            ):
+
         """Constructor for the ProtectionJobRunStats class"""
 
         # Initialize members of the class
-        self.queue_duration_usecs = queue_duration_usecs
         self.total_bytes_tiered = total_bytes_tiered
         self.admitted_time_usecs = admitted_time_usecs
         self.end_time_usecs = end_time_usecs
@@ -138,6 +138,7 @@ class ProtectionJobRunStats(object):
         self.num_successful_app_objects = num_successful_app_objects
         self.num_successful_tasks = num_successful_tasks
         self.permit_grant_time_usecs = permit_grant_time_usecs
+        self.queue_duration_usecs = queue_duration_usecs
         self.start_time_usecs = start_time_usecs
         self.time_taken_usecs = time_taken_usecs
         self.total_bytes_read_from_source = total_bytes_read_from_source
@@ -146,7 +147,6 @@ class ProtectionJobRunStats(object):
         self.total_physical_backup_size_bytes = total_physical_backup_size_bytes
         self.total_source_size_bytes = total_source_size_bytes
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -165,18 +165,18 @@ class ProtectionJobRunStats(object):
             return None
 
         # Extract variables from the dictionary
-        queue_duration_usecs = dictionary.get('QueueDurationUsecs')
         total_bytes_tiered = dictionary.get('TotalBytesTiered')
         admitted_time_usecs = dictionary.get('admittedTimeUsecs')
         end_time_usecs = dictionary.get('endTimeUsecs')
         num_app_instances = dictionary.get('numAppInstances')
-        num_failed_app_objects = dictionary.get('numFailedAppObjects')
         num_canceled_tasks = dictionary.get('numCanceledTasks')
         num_cancelled_app_objects = dictionary.get('numCancelledAppObjects')
+        num_failed_app_objects = dictionary.get('numFailedAppObjects')
         num_failed_tasks = dictionary.get('numFailedTasks')
         num_successful_app_objects = dictionary.get('numSuccessfulAppObjects')
         num_successful_tasks = dictionary.get('numSuccessfulTasks')
         permit_grant_time_usecs = dictionary.get('permitGrantTimeUsecs')
+        queue_duration_usecs = dictionary.get('queueDurationUsecs')
         start_time_usecs = dictionary.get('startTimeUsecs')
         time_taken_usecs = dictionary.get('timeTakenUsecs')
         total_bytes_read_from_source = dictionary.get('totalBytesReadFromSource')
@@ -186,24 +186,24 @@ class ProtectionJobRunStats(object):
         total_source_size_bytes = dictionary.get('totalSourceSizeBytes')
 
         # Return an object of this model
-        return cls(queue_duration_usecs,
-                   total_bytes_tiered,
-                   admitted_time_usecs,
-                   end_time_usecs,
-                   num_app_instances,
-                   num_canceled_tasks,
-                   num_cancelled_app_objects,
-                   num_failed_app_objects,
-                   num_failed_tasks,
-                   num_successful_app_objects,
-                   num_successful_tasks,
-                   permit_grant_time_usecs,
-                   start_time_usecs,
-                   time_taken_usecs,
-                   total_bytes_read_from_source,
-                   total_bytes_to_read_from_source,
-                   total_logical_backup_size_bytes,
-                   total_physical_backup_size_bytes,
-                   total_source_size_bytes)
-
-
+        return cls(
+            total_bytes_tiered,
+            admitted_time_usecs,
+            end_time_usecs,
+            num_app_instances,
+            num_canceled_tasks,
+            num_cancelled_app_objects,
+            num_failed_app_objects,
+            num_failed_tasks,
+            num_successful_app_objects,
+            num_successful_tasks,
+            permit_grant_time_usecs,
+            queue_duration_usecs,
+            start_time_usecs,
+            time_taken_usecs,
+            total_bytes_read_from_source,
+            total_bytes_to_read_from_source,
+            total_logical_backup_size_bytes,
+            total_physical_backup_size_bytes,
+            total_source_size_bytes
+)
\ No newline at end of file
