@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class PstParameters(object):
 
@@ -8,25 +7,28 @@ class PstParameters(object):
 
     Specifies PST conversion details.
 
+
     Attributes:
+
         create_pst (bool): Specifies if create a PST or MSG for input items.
-          For 6.6 we always set this to true.
+            For 6.6 we always set this to true.
         pst_password (string): Specifies Password to be set for generated PSTs.
         pst_size_threshold (long|int): Specifies PST size threshold in bytes.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "create_pst":'createPst',
         "pst_password":'pstPassword',
-        "pst_size_threshold":'pstSizeThreshold'
+        "pst_size_threshold":'pstSizeThreshold',
     }
-
     def __init__(self,
                  create_pst=None,
                  pst_password=None,
-                 pst_size_threshold=None):
+                 pst_size_threshold=None,
+            ):
+
         """Constructor for the PstParameters class"""
 
         # Initialize members of the class
@@ -34,7 +36,6 @@ class PstParameters(object):
         self.pst_password = pst_password
         self.pst_size_threshold = pst_size_threshold
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -58,8 +59,8 @@ class PstParameters(object):
         pst_size_threshold = dictionary.get('pstSizeThreshold')
 
         # Return an object of this model
-        return cls(create_pst,
-                   pst_password,
-                   pst_size_threshold)
-
-
+        return cls(
+            create_pst,
+            pst_password,
+            pst_size_threshold
+)
\ No newline at end of file
