@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
-import cohesity_management_sdk.models.root_public_folder
 import cohesity_management_sdk.models.protection_source
+import cohesity_management_sdk.models.root_public_folder
+
 
 class PublicFoldersRestoreParameters(object):
 
@@ -11,29 +12,31 @@ class PublicFoldersRestoreParameters(object):
     Specifies information needed for recovering O365 Public Folders in
     O365Publicfolders environment.
 
-    Attributes:
-        root_public_folder_list (list of RootPublicFolder): Specifies the list of Public Folders
-            to be restored.
-        target_folder_path (string): Specifies the target folder path to restore
-            the Public Folders.
-        target_root_public_folder (ProtectionSource): Specifies the destination Public
-            Folder where the Public Folders specified within RootPublicFolders
-            will be restored with their appropriate paths. Unread Notification
-            Count.
 
+    Attributes:
+
+        root_public_folder_list (list of RootPublicFolder): Specifies the list
+            of Public Folders to be restored.
+        target_folder_path (string): Specifies the target folder path to
+            restore the Public Folders.
+        target_root_public_folder (ProtectionSource): Specifies the destination
+            Public Folder where the Public Folders specified within
+            RootPublicFolders will be restored with their appropriate paths.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "root_public_folder_list":'rootPublicFolderList',
         "target_folder_path":'targetFolderPath',
-        "target_root_public_folder":'targetRootPublicFolder'
+        "target_root_public_folder":'targetRootPublicFolder',
     }
-
     def __init__(self,
                  root_public_folder_list=None,
                  target_folder_path=None,
-                 target_root_public_folder=None):
+                 target_root_public_folder=None,
+            ):
+
         """Constructor for the PublicFoldersRestoreParameters class"""
 
         # Initialize members of the class
@@ -41,7 +44,6 @@ class PublicFoldersRestoreParameters(object):
         self.target_folder_path = target_folder_path
         self.target_root_public_folder = target_root_public_folder
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -69,8 +71,8 @@ class PublicFoldersRestoreParameters(object):
         target_root_public_folder = cohesity_management_sdk.models.protection_source.ProtectionSource.from_dictionary(dictionary.get('targetRootPublicFolder')) if dictionary.get('targetRootPublicFolder') else None
 
         # Return an object of this model
-        return cls(root_public_folder_list,
-                   target_folder_path,
-                   target_root_public_folder)
-
-
+        return cls(
+            root_public_folder_list,
+            target_folder_path,
+            target_root_public_folder
+)
\ No newline at end of file
