@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class RestoreAdGuidPair(object):
 
@@ -8,31 +7,33 @@ class RestoreAdGuidPair(object):
 
     RestoreAdGuidPair is the AD object guid string pair.
 
+
     Attributes:
+
         destination (string): Specifies the destination guid in production AD
-            object corresponding to source. If empty, it assumed to be
-            'source' guid.
+            object corresponding to source. If empty, it assumed to be 'source'
+            guid.
         source (string): Specifies the source guid string of an AD object in
             mounted AD snapshot. This cannot be empty.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "destination":'destination',
-        "source":'source'
+        "source":'source',
     }
-
     def __init__(self,
                  destination=None,
-                 source=None):
+                 source=None,
+            ):
+
         """Constructor for the RestoreAdGuidPair class"""
 
         # Initialize members of the class
         self.destination = destination
         self.source = source
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -55,7 +56,7 @@ class RestoreAdGuidPair(object):
         source = dictionary.get('source')
 
         # Return an object of this model
-        return cls(destination,
-                   source)
-
-
+        return cls(
+            destination,
+            source
+)
\ No newline at end of file
