@@ -1,18 +1,16 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class ResultTypeEnum(object):
 
     """Implementation of the 'ResultType' enum.
-
     Specifies the type of the result returned after performing the internal
-    host check.
-    Specifies the type of the host check result performed internally.
-    'kPass' indicates that the respective check was successful.
+    host check. Specifies the type of the host check result performed
+    internally. 'kPass' indicates that the respective check was successful.
     'kFail' indicates that the respective check failed as some mandatory
-    setting is not met
-    'kWarning' indicates that the respective check has warning as certain
-    non-mandatory setting is not met.
+    setting is not met 'kWarning' indicates that the respective check has
+    warning as certain non-mandatory setting is not met.
+
 
     Attributes:
         KPASS: TODO: type description here.
@@ -26,4 +24,3 @@ class ResultTypeEnum(object):
     KFAIL = 'kFail'
 
     KWARNING = 'kWarning'
-
