@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class Route(object):
 
@@ -8,7 +7,10 @@ class Route(object):
 
     Specifies the settings of a Static Route.
 
+
     Attributes:
+
+        advmss (int): Specifies AdvMss setting per route.
         description (string): Specifies a description of the Static Route.
         dest_network (string): Destination network.  Specifies the destination
             network of the Static Route. overrideDescription: true
@@ -19,33 +21,37 @@ class Route(object):
             destination network.
         mtu (int): Specifies MTU setting per route.
         next_hop (string): Specifies the next hop to the destination network.
-        node_group_name (string): Specifies the network node group to
-            represent a group of nodes.
-
+        node_group_name (string): Specifies the network node group to represent
+            a group of nodes.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
+        "advmss":'advmss',
         "description":'description',
         "dest_network":'destNetwork',
         "if_name":'ifName',
         "iface_group_name":'ifaceGroupName',
         "mtu":'mtu',
         "next_hop":'nextHop',
-        "node_group_name":'nodeGroupName'
+        "node_group_name":'nodeGroupName',
     }
-
     def __init__(self,
+                 advmss=None,
                  description=None,
                  dest_network=None,
                  if_name=None,
                  iface_group_name=None,
                  mtu=None,
                  next_hop=None,
-                 node_group_name=None):
+                 node_group_name=None,
+            ):
+
         """Constructor for the Route class"""
 
         # Initialize members of the class
+        self.advmss = advmss
         self.description = description
         self.dest_network = dest_network
         self.if_name = if_name
@@ -54,7 +60,6 @@ class Route(object):
         self.next_hop = next_hop
         self.node_group_name = node_group_name
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -73,6 +78,7 @@ class Route(object):
             return None
 
         # Extract variables from the dictionary
+        advmss = dictionary.get('advmss')
         description = dictionary.get('description')
         dest_network = dictionary.get('destNetwork')
         if_name = dictionary.get('ifName')
@@ -82,12 +88,13 @@ class Route(object):
         node_group_name = dictionary.get('nodeGroupName')
 
         # Return an object of this model
-        return cls(description,
-                   dest_network,
-                   if_name,
-                   iface_group_name,
-                   mtu,
-                   next_hop,
-                   node_group_name)
-
-
+        return cls(
+            advmss,
+            description,
+            dest_network,
+            if_name,
+            iface_group_name,
+            mtu,
+            next_hop,
+            node_group_name
+)
\ No newline at end of file
