@@ -1,12 +1,15 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class RunNowPhysicalParameters(object):
 
     """Implementation of the 'RunNowPhysicalParameters' model.
 
+    Specifies optional physical parameters for a specific source id.
+
+
     Attributes:
+
         metadata_file_path (string): Specifies metadata file path during
             run-now requests for physical file based backups for some specific
             host entity. If specified, it will override any default
@@ -16,19 +19,20 @@ class RunNowPhysicalParameters(object):
             field for that host during run-now request will be rejected.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "metadata_file_path":'metadataFilePath'
+        "metadata_file_path":'metadataFilePath',
     }
-
     def __init__(self,
-                 metadata_file_path=None):
+                 metadata_file_path=None,
+            ):
+
         """Constructor for the RunNowPhysicalParameters class"""
 
         # Initialize members of the class
         self.metadata_file_path = metadata_file_path
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -50,6 +54,6 @@ class RunNowPhysicalParameters(object):
         metadata_file_path = dictionary.get('metadataFilePath')
 
         # Return an object of this model
-        return cls(metadata_file_path)
-
-
+        return cls(
+            metadata_file_path
+)
\ No newline at end of file
