@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
-import cohesity_management_sdk.models.account_entitlement
+# Copyright 2023 Cohesity Inc.
 
 class SalesforceAccountInfo(object):
 
@@ -9,48 +7,64 @@ class SalesforceAccountInfo(object):
 
     Salesforce Account Information of a Helios user.
 
+
     Attributes:
+
         account_id (string): Specifies the Account Id assigned by Salesforce.
-        entitlements (list of AccountEntitlement): Specifies the entitlements
-            available to the account.
+        helios_access_grant_status (string): Specifies the status of helios
+            access.
+        is_d_gaa_s_user (bool): Specifies whether user is a DGaaS licensed
+            user.
         is_d_maa_s_user (bool): Specifies whether user is a DMaaS licensed
             user.
+        is_draa_s_user (bool): Specifies whether user is a DRaaS licensed user.
+        is_r_paa_s_user (bool): Specifies whether user is a RPaaS licensed
+            user.
         is_sales_user (bool): Specifies whether user is a Sales person from
             Cohesity.
-        is_support_user (bool): Specifies whether user is a support person
-            from Cohesity.
+        is_support_user (bool): Specifies whether user is a support person from
+            Cohesity.
         user_id (string): Specifies the User Id assigned by Salesforce.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "account_id":'accountId',
-        "entitlements":'entitlements',
+        "helios_access_grant_status":'heliosAccessGrantStatus',
+        "is_d_gaa_s_user":'isDGaaSUser',
         "is_d_maa_s_user":'isDMaaSUser',
+        "is_draa_s_user":'isDRaaSUser',
+        "is_r_paa_s_user":'isRPaaSUser',
         "is_sales_user":'isSalesUser',
         "is_support_user":'isSupportUser',
-        "user_id":'userId'
+        "user_id":'userId',
     }
-
     def __init__(self,
                  account_id=None,
-                 entitlements=None,
+                 helios_access_grant_status=None,
+                 is_d_gaa_s_user=None,
                  is_d_maa_s_user=None,
+                 is_draa_s_user=None,
+                 is_r_paa_s_user=None,
                  is_sales_user=None,
                  is_support_user=None,
-                 user_id=None):
+                 user_id=None,
+            ):
+
         """Constructor for the SalesforceAccountInfo class"""
 
         # Initialize members of the class
         self.account_id = account_id
-        self.entitlements = entitlements
+        self.helios_access_grant_status = helios_access_grant_status
+        self.is_d_gaa_s_user = is_d_gaa_s_user
         self.is_d_maa_s_user = is_d_maa_s_user
+        self.is_draa_s_user = is_draa_s_user
+        self.is_r_paa_s_user = is_r_paa_s_user
         self.is_sales_user = is_sales_user
         self.is_support_user = is_support_user
         self.user_id = user_id
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -70,22 +84,24 @@ class SalesforceAccountInfo(object):
 
         # Extract variables from the dictionary
         account_id = dictionary.get('accountId')
-        entitlements = None
-        if dictionary.get('entitlements') != None:
-            entitlements = list()
-            for structure in dictionary.get('entitlements'):
-                entitlements.append(cohesity_management_sdk.models.account_entitlement.AccountEntitlement.from_dictionary(structure))
+        helios_access_grant_status = dictionary.get('heliosAccessGrantStatus')
+        is_d_gaa_s_user = dictionary.get('isDGaaSUser')
         is_d_maa_s_user = dictionary.get('isDMaaSUser')
+        is_draa_s_user = dictionary.get('isDRaaSUser')
+        is_r_paa_s_user = dictionary.get('isRPaaSUser')
         is_sales_user = dictionary.get('isSalesUser')
         is_support_user = dictionary.get('isSupportUser')
         user_id = dictionary.get('userId')
 
         # Return an object of this model
-        return cls(account_id,
-                   entitlements,
-                   is_d_maa_s_user,
-                   is_sales_user,
-                   is_support_user,
-                   user_id)
-
-
+        return cls(
+            account_id,
+            helios_access_grant_status,
+            is_d_gaa_s_user,
+            is_d_maa_s_user,
+            is_draa_s_user,
+            is_r_paa_s_user,
+            is_sales_user,
+            is_support_user,
+            user_id
+)
\ No newline at end of file
