@@ -1,37 +1,38 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class SequenceNumber(object):
 
     """Implementation of the 'SequenceNumber' model.
 
-    Sequence Number for each change for MongoDB Entity.
+    TODO: type description here.
+
 
     Attributes:
-        timestamp (long|int): Timestamp field of the change event.
-            Mongodb associates each change with a timestamp type which is a 64
-            bit value where:
-            The most significant 32 bits are a time_t value (seconds since the
-            Unix epoch), the least significant 32 bits are an incrementing
-            ordinal for operations within a given second. Note that the
-            timestamps of events are not consecutive numbers and also we can
-            have multiple colocated changes entries for same timestamp.
+
+        timestamp (long|int): Timestamp field of the change event. Mongodb
+            associates each change with a timestamp type which is a 64 bit
+            value where: The most significant 32 bits are a time_t value
+            (seconds since the Unix epoch), the least significant 32 bits are
+            an incrementing ordinal for operations within a given second. Note
+            that the timestamps of events are not consecutive numbers and also
+            we can have multiple colocated changes entries for same timestamp.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "timestamp":'timestamp'
+        "timestamp":'timestamp',
     }
-
     def __init__(self,
-                 timestamp=None):
+                 timestamp=None,
+            ):
+
         """Constructor for the SequenceNumber class"""
 
         # Initialize members of the class
         self.timestamp = timestamp
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -53,6 +54,6 @@ class SequenceNumber(object):
         timestamp = dictionary.get('timestamp')
 
         # Return an object of this model
-        return cls(timestamp)
-
-
+        return cls(
+            timestamp
+)
\ No newline at end of file
