@@ -1,14 +1,13 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class SeverityEnum(object):
 
     """Implementation of the 'Severity' enum.
+    Specifies the severity level of an Alert. kCritical - Alerts whose severity
+    type is Critical. kWarning - Alerts whose severity type is Warning. kInfo -
+    Alerts whose severity type is Info.
 
-    Specifies the severity level of an Alert.
-    kCritical - Alerts whose severity type is Critical.
-    kWarning - Alerts whose severity type is Warning.
-    kInfo - Alerts whose severity type is Info.
 
     Attributes:
         KCRITICAL: TODO: type description here.
@@ -22,4 +21,3 @@ class SeverityEnum(object):
     KWARNING = 'kWarning'
 
     KINFO = 'kInfo'
-
