@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class ShareTypeEnum(object):
 
     """Implementation of the 'ShareType' enum.
-
     Specifies the sharing protocol type used to mount the file system.
-    Currently, only NFS is supported.
-    'kNFS' indicates use the NFS protocol to mount the file system.
-    'kCIFS' indicates use the CIFS protocol to mount the file system.
+    Currently, only NFS is supported. 'kNFS' indicates use the NFS protocol to
+    mount the file system. 'kCIFS' indicates use the CIFS protocol to mount the
+    file system.
+
 
     Attributes:
         KNFS: TODO: type description here.
@@ -19,4 +19,3 @@ class ShareTypeEnum(object):
     KNFS = 'kNFS'
 
     KCIFS = 'kCIFS'
-
