@@ -1,32 +1,33 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class ShowSystemLedInfoResult(object):
 
     """Implementation of the 'ShowSystemLedInfoResult' model.
 
-    Specifies the result returned after a successful request to show system
-    LED details.
+    Specifies the result returned after a successful request to show system LED
+    details.
+
 
     Attributes:
-        led_info (string): TODO: type description here.
 
+        led_info (string): TODO: Type description here.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "led_info":'ledInfo'
+        "led_info":'ledInfo',
     }
-
     def __init__(self,
-                 led_info=None):
+                 led_info=None,
+            ):
+
         """Constructor for the ShowSystemLedInfoResult class"""
 
         # Initialize members of the class
         self.led_info = led_info
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -48,6 +49,6 @@ class ShowSystemLedInfoResult(object):
         led_info = dictionary.get('ledInfo')
 
         # Return an object of this model
-        return cls(led_info)
-
-
+        return cls(
+            led_info
+)
\ No newline at end of file
